#
# spec file for package gtk4
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Dominique Leuenebrger, Amsterdam, Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gtk_binary_version 4.0.0
%define _name gtk

%bcond_without gst

# disable gstreamer media player when bootstrapping on workbench
%if 0%{?workbench_version} > 0
%bcond_with gst
%endif

Name:           gtk4
Version:        4.18.2
Release:        1.1
Summary:        The GTK+ toolkit library (version 4)
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://www.gtk.org/

Source:         %{_name}-%{version}.tar.zst
Source2:        settings.ini
Source3:        macros.gtk4
Source99:       gtk4-rpmlintrc

# Temporarily revert this until we figure out how to best restore
# private requires that are needed for rpm automatic dep extraction.
# https://gitlab.gnome.org/GNOME/gtk/-/merge_requests/4756
# PATCH-FIX-OPENSUSE 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch -- Revert "Meson: Simplify pkgconfig file generator"
Patch0:         0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch

BuildRequires:  cups-devel >= 2.0
# We do not support building against cups 2.3 betas
BuildConflicts: (cups-devel > 2.3 with cups-devel < 2.3.0)
%if 0%{?sle_version} && 0%{?sle_version} <= 150400
BuildRequires:  Mesa-libGLESv2-devel
%endif
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docutils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.50.1
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  shaderc
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atk) >= 2.15.1
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(cairo) >= 1.14.0
BuildRequires:  pkgconfig(cairo-gobject) >= 1.14.0
BuildRequires:  pkgconfig(cloudproviders) >= 0.3.1
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(epoxy) >= 1.4
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.30.0
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(glib-2.0) >= 2.80.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.80.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.72.0
BuildRequires:  pkgconfig(graphene-1.0) >= 1.10.0
BuildRequires:  pkgconfig(graphene-gobject-1.0) >= 1.10.0
BuildRequires:  pkgconfig(vulkan)
%if %{with gst}
BuildRequires:  pkgconfig(gstreamer-gl-1.0)
BuildRequires:  pkgconfig(gstreamer-player-1.0)
%endif
BuildRequires:  pkgconfig(harfbuzz) >= 8.4
BuildRequires:  pkgconfig(iso-codes)
# Disabled until upstream enables ffmpeg support by default
# BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(pango) >= 1.55.0
BuildRequires:  pkgconfig(pangocairo) >= 1.14.0
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(tracker-sparql-3.0)
BuildRequires:  pkgconfig(wayland-client) >= 1.21.0
BuildRequires:  pkgconfig(wayland-cursor) >= 1.9.91
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.36
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr) >= 1.2.99

%description
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package -n libgtk-4-1
Summary:        The GTK+ toolkit library (version 4)
# gtk4-data is currently not being built, might be an upstream oversight though
Group:          System/Libraries
Requires:       %{name}-schema >= %{version}
# Require Adwaita Icon Theme: It's GTKs icon set, that's guaranteed to be there
Requires:       adwaita-icon-theme
# While hicolor is not a Requires strictly speaking, we put it as
# such instead of as a Recommends because many applications just
# assume it's there and we need to have a low-level package to
# bring it in.
Requires:       hicolor-icon-theme
# gtk+ can work without branding/translations. Built in defaults will be used then.
Recommends:     %{name}-branding
Recommends:     gvfs
Obsoletes:      %{name}-data
# IM modules have been dropped in 3.94.0
Obsoletes:      %{name}-immodule-amharic
Obsoletes:      %{name}-immodule-broadway
Obsoletes:      %{name}-immodule-inuktitut
Obsoletes:      %{name}-immodule-multipress
Obsoletes:      %{name}-immodule-thai
Obsoletes:      %{name}-immodule-tigrigna
Obsoletes:      %{name}-immodule-vietnamese
Obsoletes:      %{name}-immodule-xim
# with version 4.0.0, the soname was actually changed to libgtk-4.so.1
# but the package was nor correctly renamed
Obsoletes:      libgtk-4-0 >= 4
# Provide main package to make the lang subpackage installable
Provides:       %{name} = %{version}

%description -n libgtk-4-1
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package -n typelib-1_0-Gtk-4_0
Summary:        Introspection bindings for the GTK+ toolkit library v4
Group:          System/Libraries
Requires:       (python3-gobject-Gdk if python3-gobject)
Requires:       (python310-gobject-Gdk if python310-gobject)
Requires:       (python38-gobject-Gdk if python38-gobject)
Requires:       (python39-gobject-Gdk if python39-gobject)

%description -n typelib-1_0-Gtk-4_0
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides the GObject Introspection bindings for GTK+.

%package tools
Summary:        Auxiliary utilities for the GTK+ toolkit library v4
Group:          System/Libraries

%description tools
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package devel-tools
Summary:        Auxiliary utilities for the GTK+ toolkit library v4
Group:          System/Libraries

%description devel-tools
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package schema
Summary:        Config schema for the GTK+ toolkit library v4
# The schema is shared between gtk3 and gtk4 - gtk4 wins
Group:          System/Libraries
BuildArch:      noarch

%description schema
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package branding-upstream
Summary:        Upstream theme configuration for the GTK+ toolkit library v4
Group:          System/Libraries
Requires:       libgtk-4-1 = %{version}
Supplements:    (libgtk-4-1 and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: Provides /usr/share/gtk-4.0/settings.ini, to define default theme and icon
#BRAND: theme.
#BRAND: Do not forget to add proper Requires in branding package if changing
#BRAND: those.

%description branding-upstream
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides the upstream theme configuration for widgets and
icon themes.

%package docs
Summary:        Developer documentation for GTK
BuildArch:      noarch

%description docs
This package contains developer documentation for version 4 of the GTK
widget toolkit.

%package devel
Summary:        Development files for the GTK+ toolkit library v4
Group:          Development/Libraries/X11
Requires:       %{name}-devel-tools = %{version}
Requires:       %{name}-tools = %{version}
Requires:       gettext-its-%{name} >= %{version}
Requires:       libgtk-4-1 = %{version}
Requires:       typelib-1_0-Gtk-4_0 = %{version}

%description devel
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package contains the development files for GTK+ 4.x.

%package -n gettext-its-%{name}
Summary:        International Tag Set for GTK+ 4
# The ITS is compatible between GTK3 and GTK4
Group:          Development/Libraries/X11
Provides:       gettext-its-gtk3 = %{version}
Obsoletes:      gettext-its-gtk3 < %{version}

%description -n gettext-its-%{name}
This package enhances gettext with an International Tag Set for GTK+ 4

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
export CFLAGS="%{optflags} -Wno-int-conversion"
%meson \
	-Ddocumentation=true \
	-Dbroadway-backend=true \
	-Dcloudproviders=enabled \
	-Dcolord=enabled \
	-Dprint-cups=enabled \
	-Dwayland-backend=true \
	-Dx11-backend=true \
	-Dintrospection=enabled \
	-Dman-pages=true \
	-Dtracker=enabled \
%if %{with gst}
	-Dmedia-gstreamer=enabled \
%else
	-Dmedia-gstreamer=disabled \
%endif
	-Dbuild-testsuite=false \
	-Dbuild-tests=false \
	-Dbuild-examples=false \
	%{nil}
%meson_build

%install
%meson_install

%find_lang gtk40 %{?no_lang_C}
install -m 644 -D %{SOURCE2} %{buildroot}%{_datadir}/gtk-4.0/settings.ini
# create modules directory that should have been created during the build
if test ! -d %{buildroot}%{_libdir}/gtk-4.0/modules; then
  mkdir %{buildroot}%{_libdir}/gtk-4.0/modules
else
  echo 'Remove this no-longer-needed modulesdir hack.'
fi
# create theming-engines directory that should have been created during the build
if test ! -d %{buildroot}%{_libdir}/gtk-4.0/%{gtk_binary_version}/theming-engines; then
  mkdir %{buildroot}%{_libdir}/gtk-4.0/%{gtk_binary_version}/theming-engines
else
  echo 'Remove this no-longer-needed themingdir hack.'
fi
# Install rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
cp %{SOURCE3} %{buildroot}%{_rpmmacrodir}
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{_libdir}

%ldconfig_scriptlets -n libgtk-4-1

%files -n libgtk-4-1
%license COPYING
%doc AUTHORS NEWS
%dir %{_libdir}/gtk-4.0
%dir %{_libdir}/gtk-4.0/%{gtk_binary_version}
%dir %{_libdir}/gtk-4.0/%{gtk_binary_version}/printbackends/
%{_libdir}/gtk-4.0/%{gtk_binary_version}/printbackends/libprintbackend-cups.so
%{_libdir}/gtk-4.0/%{gtk_binary_version}/printbackends/libprintbackend-file.so
%if %{with gst}
%dir %{_libdir}/gtk-4.0/%{gtk_binary_version}/media/
#%%{_libdir}/gtk-4.0/%%{gtk_binary_version}/media/libmedia-ffmpeg.so
%{_libdir}/gtk-4.0/%{gtk_binary_version}/media/libmedia-gstreamer.so
%endif
%dir %{_libdir}/gtk-4.0/%{gtk_binary_version}/theming-engines/
%dir %{_libdir}/gtk-4.0/modules
%{_libdir}/libgtk-4.so.*

%files -n typelib-1_0-Gtk-4_0
%{_libdir}/girepository-1.0/Gdk-4.0.typelib
%{_libdir}/girepository-1.0/GdkWayland-4.0.typelib
%{_libdir}/girepository-1.0/GdkX11-4.0.typelib
%{_libdir}/girepository-1.0/Gsk-4.0.typelib
%{_libdir}/girepository-1.0/Gtk-4.0.typelib

%files tools
%{_bindir}/gtk4-broadwayd
%{_bindir}/gtk4-launch
%{_bindir}/gtk4-path-tool
%{_bindir}/gtk4-query-settings
%{_bindir}/gtk4-update-icon-cache
%dir %{_datadir}/gtk-4.0/emoji
%{_datadir}/gtk-4.0/emoji/*.gresource
%{_mandir}/man1/gtk4-broadwayd.1%{?ext_man}
%{_mandir}/man1/gtk4-launch.1%{?ext_man}
%{_mandir}/man1/gtk4-query-settings.1%{?ext_man}
%{_mandir}/man1/gtk4-update-icon-cache.1%{?ext_man}
# English should be offered to every installation by default.
%{_datadir}/locale/en/
%{_datadir}/locale/en_GB/
%{_datadir}/locale/en@shaw/
%{_datadir}/locale/en_CA/

%files devel-tools
%{_bindir}/gtk4-builder-tool
%{_bindir}/gtk4-demo
%{_bindir}/gtk4-demo-application
%{_bindir}/gtk4-encode-symbolic-svg
%{_bindir}/gtk4-image-tool
%{_bindir}/gtk4-node-editor
%{_bindir}/gtk4-print-editor
%{_bindir}/gtk4-rendernode-tool
%{_bindir}/gtk4-widget-factory
%{_datadir}/applications/org.gtk.Demo4.desktop
%{_datadir}/applications/org.gtk.gtk4.NodeEditor.desktop
%{_datadir}/applications/org.gtk.PrintEditor4.desktop
%{_datadir}/applications/org.gtk.WidgetFactory4.desktop
%dir %{_datadir}/gtk-4.0
%{_datadir}/gtk-4.0/gtk4builder.rng
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.Demo4.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.gtk4.NodeEditor.Devel.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.gtk4.NodeEditor.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gtk.gtk4.NodeEditor-symbolic.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.PrintEditor4.Devel.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.PrintEditor4.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gtk.WidgetFactory4.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gtk.Demo4-symbolic.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gtk.PrintEditor4-symbolic.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gtk.WidgetFactory4-symbolic.svg
# This schemas file stays here and not in the schemas package
%{_datadir}/glib-2.0/schemas/org.gtk.Demo4.gschema.xml
%{_datadir}/metainfo/org.gtk.Demo4.appdata.xml
%{_datadir}/metainfo/org.gtk.gtk4.NodeEditor.appdata.xml
%{_datadir}/metainfo/org.gtk.PrintEditor4.appdata.xml
%{_datadir}/metainfo/org.gtk.WidgetFactory4.appdata.xml
%{_mandir}/man1/gtk4-builder-tool.1%{?ext_man}
%{_mandir}/man1/gtk4-demo-application.1%{?ext_man}
%{_mandir}/man1/gtk4-demo.1%{?ext_man}
%{_mandir}/man1/gtk4-encode-symbolic-svg.1%{?ext_man}
%{_mandir}/man1/gtk4-image-tool.1%{?ext_man}
%{_mandir}/man1/gtk4-node-editor.1%{?ext_man}
%{_mandir}/man1/gtk4-path-tool.1%{?ext_man}
%{_mandir}/man1/gtk4-rendernode-tool.1%{?ext_man}
%{_mandir}/man1/gtk4-widget-factory.1%{?ext_man}

%files schema
%{_datadir}/glib-2.0/schemas/org.gtk.gtk4.Settings.ColorChooser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.gtk4.Settings.Debug.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.gtk4.Settings.EmojiChooser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.gtk4.Settings.FileChooser.gschema.xml

%files branding-upstream
%{_datadir}/gtk-4.0/settings.ini

%files docs
%{_datadir}/doc/gdk4/
%{_datadir}/doc/gdk4-wayland/
%{_datadir}/doc/gdk4-x11/
%{_datadir}/doc/gsk4/
%{_datadir}/doc/gtk4/

%files devel
%doc CONTRIBUTING.md
%{_datadir}/gir-1.0/*.gir
%{_includedir}/gtk-4.0/
%{_libdir}/pkgconfig/gtk4.pc
%{_libdir}/pkgconfig/gtk4-atspi.pc
%{_libdir}/pkgconfig/gtk4-broadway.pc
%{_libdir}/pkgconfig/gtk4-wayland.pc
%{_libdir}/pkgconfig/gtk4-unix-print.pc
%{_libdir}/pkgconfig/gtk4-x11.pc
%{_libdir}/libgtk-4.so
%{_rpmmacrodir}/macros.gtk4
%dir %{_datadir}/gtk-4.0/valgrind
%{_datadir}/gtk-4.0/valgrind/gtk.supp

%files -n gettext-its-%{name}
%dir %{_datadir}/gettext/
%dir %{_datadir}/gettext/its/
%{_datadir}/gettext/its/gtk4builder.its
%{_datadir}/gettext/its/gtk4builder.loc

%files lang -f gtk40.lang
# Those shouldn't be here in the first place.
%exclude %{_datadir}/locale/en/
%exclude %{_datadir}/locale/en_GB/
%exclude %{_datadir}/locale/en@shaw/
%exclude %{_datadir}/locale/en_CA/

%changelog
* Mon Mar 17 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.18.2:
  + GtkPopoverMenu: Fix a sporatic crash that affected Showtime
  + X11: Fix interactions between scaling and the cairo renderer
    that broke the mutter-x11-frame client
  + Bugs fixed:
  - Segfault on setting popover child of a MenuButton
  - Transparent/bugged close button on titlebar in 48.rc
  - `AdwTabOverview` only works with the vulkan renderer
  - clipboard: Plug a memory leak
  - wayland: Avoid leaks in drag surfaces
  - roaring: Use g_malloc/g_free
  + Updated translations.
* Sat Mar 15 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.18.1:
  + Bugs fixed:
  - Deadkeys using UFDD modifiers do not work under gtk4 apps
  - recorder.ui's action items made available for translation
  - Trying to measure GtkPopover 0x42761b0 for height of 277, but
    it needs at least 313
  - Nautilus crashes when try to pin any folder as a new bookmark
    on the side panel
  - treeview: Drop cell-only states when rendering the empty
    bottom area
  - paned: Fix handle jump on drag start
  - Revamp the portal check
  - fix: Fix the type conversion (gtk demo) in the gtkgear
    example
  - bitset: Fix annotations
  - Add another font testcase
  - inspector: Make editing attributes work
  - docs: Add some a11y references
  - docs: fix typo
  - inspector: Don't translate action names
  - macos: Fix HiDPI rendering on macOS
  - call nproc once in gdk parallel
  - docs: Clarify invalidation replacements
  - android: Introduced partial OpenGL backend
  - Tweak text layout
  - inspector: Allow editing PangoTabArrays
  - egl: modifers must be an array
  - gpu: Make sure we actually download dmabuf textures again
  - Make color management opt-in
  - Improve key event logging
  - Tweak font rendering more
  - API: Deprecate gdk_surface_create_cairo_context()
  - Use gtk_shell version to announce wl_surface.offset support
    for cursors
  - gsk: Fix multiple clipping of partial pixels
  - vulkan: Prepare for Vulkan using wp-color-v1
  - gsk: Pad text node bounds
  - window: Fix destroying with transient parent
  - stack: Fix adjusting child allocation
  + Updated translations.
* Wed Mar  5 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.6 (Unstable):
  + GSK rendering issues on Asahi Linux are fixed
  + Buffer sizing issues with fractional scaling are fixed
  + GtkFontChooser scrolls to the initially selected font
  + Font rendering with the new default GNOME font is improved
  + The Wayland cursor shape protocol is supported
  + Initial focus for popups on Android is fixed
  + Various bugs fixed
  + Updated translations.
* Mon Feb 24 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.5 (Unstable):
  + Numeric mode in GtkSpinButtons works again
  + Client-side dialogs can be made fully modal
  + Portals work better for unsandboxed apps, by registering
  + Editable labels have a context menu
  + GtkListBox size allocation has been improved
  + We require wayland 1.23 and wayland-protocols 1.41
  + We use the wp_color_manager_v1 protocol for color management
    under Wayland
  + Most screenshots in the documentation have a dark variant
  + GtkBuilder allows inline definition for GMenu-valued properties
  + Various bugs fixed
  + Updated translations.
* Sat Feb  1 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.4 (Unstable):
  + GtkFileChooser: Stop replacing : (colon) with U+2236 (ratio)
  + GtkSpinButton: Avoid out-of-bounds values in some cases
  + GtkWindow:
  - Send expected a11y events when a window is closed
  - Change accessible role back to GTK_ACCESSIBLE_ROLE_WINDOW
  + GtkLabel: Make context menus keyboard-navigatable
  + GtkVideo: Support rotated videos
  + GDK:
  - Add a way to retrieve keyboard layout information
  - Use libpng api for cicp if available
  + GSK Drop the old GL renderer
  + Accessibility: Maintain inverse relations
  + Deprecations:
  - The x11 backend
  - The Broadway backend
  + Build: Require cairo 1.18.2
  + Updated translations.
* Fri Jan 17 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.3 (Unstable):
  + GtkText:
  - Consume Ctrl-A
  - Handle Cut', Copy, Paste, Undo, and Redo keys
  - Improve a11y representation
  + GtkLabel:
  - Consume Ctrl-A when we handle it
  - Pass mnemonics to a11y
  + GtkTextView:
  - Handle Cut, Copy, Paste, Undo, and Redo keys
  - Fix disappearing carets after focus changes
  + GtkFileChooser:
  - Handle Find keys
  - Set a11y label on Search button
  - Set a11y labels on pathbar buttons
  - Pass key-shortcuts for the "New folder" button
  + GtkAppChooser: Fix sorting
  + GtkListBox: Improve a11y representation
  + GtkColumnView: Fix column dnd in right-to-left context
  + GtkWindow: Make resize corners gapless with rounded corners
  + GtkPopoverMenu: Show mnemonics on Alt press
  + GtkMenuButton: Improve a11y representation
  + GtkFileDialog:
  - Fix a crash
  - Add more text file api variants
  + GtkSizeGroup: Improve consistency measurements and allocations
  + GtkBuilder: Parse tab arrays and font descriptions in Pango
    syntax
  + Wayland:
  - Rely on scale events for pointer surfaces
  - Make idle inhibit work with fullscreen subsurfaces
  + Accessibility:
  - Implement GetKeyBinding properly for actions
  - Set key-shortcuts attribute
  - Fix state change notification for some states
  - Set application ID attribute
  + GSK: Don't double-clip edges for shadows
  + Demos:
  - widget-factory: Set alternative text on pictures
  - gtk-demo: Allow to run as a service
  + Deprecations:
  - GtkShortcutsWindow
  - Loading themes from ~/.themes
  - <child> in ui files where child properties exist
  + Updated translations.
- Rebase 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch.
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.2 (Unstable):
  + GtkWindow: Rework computing the minimum size
  + GtkPicture: Fix measuring with content-fit = scale-down
  + GtkStack:
  - Report constant size request mode in more cases
  - Avoid measuring children aginst preferred request mode
  - Fix measuring during size interpolation
  + GtkFlowBox:
  - Improve size request mode reporting
  - Fix measuring minimum height
  - Fix measuring natural width
  - Implement hfw vai binary search
  + GtkScrolledWindow:
  - Report constant size request mode in more cases
  - Skip measuring children if we can
  + GtkBox:
  - Don't always reserve height for baseline alignment
  - Rework natural opposite size-for-size computation
  - Add fast paths for some cases of measurement and allocation
  + GtkLayoutManager:
  - Skip invisible children for request mode determination
  - Prefer hfw, all things being equal
  + GtkColorPicker: Respect GDK_DEBUG=no-portals
  + GtkEntry:
  - Stop guessing text direction from keyboard layout
  - Add a shortcut and context menu item to change text direction
  + GtkSpinButton: Make numeric spin buttons always LTR
  + GtkAboutDialog: Small UI improvements
  + Accessibility: Add an AccessKit backend. Use accesskit=enabled
    to build it and GTK_A11Y=accesskit to use it
  + Wayland:
  - Always clear exported surface IDs on finalize
  - Use the correct display for imcontext
  + Vulkan: Make GdkVulkanContext work with Android armv7
  + Build:
  - Require GLib 2.80
  - Require harfbuzz 8.4
  - Require pango 1.55
  - Require C11
  + Updated translations.
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.1 (Unstable):
  + This release switches our portal support from opt-in to
    opt-out. We will use portals by default, unless you set
    GDK_DEBUG=no-portals. And we will *always* use portals in
    flatpaks.
  + Text rendering: Make error underlines smaller.
  + GtkText: Avoid selecting inserted Emoji.
  + GtkPlacesView: Improve accessibility.
  + GtkFileChooser: Fix a case where search was stealing focus.
  + GtkEmojiChooser: Update to CLDR 46 / Unicode 16.
  + Accessibility: Fix DBus signature of ChildrenChanged.
  + GDK:
  - Don't recycle threads too aggressively.
  - Add GDK_DISABLE=threads to disable threaded operations.
  - Improve parallelization for small tasks.
  + GSK:
  - Make occlusion checking more effective.
  - Clip luminosity when clipping colors (avoiding masking
    artifacts).
  - Fix problems with dihedral transforms.
  + Vulkan:
  - Streamline Vulkan setup.
  - Fix blurry rendering at certain scale/size combinations.
  + OpenGL: Conform to buffer offset alignment requirements.
  + Windows: Fix pasting certain bitmaps.
  + Documentation: Revise and modernize some docs.
  + Debugging:
  - Inspector: Show surfaces and renderers in the tree.
  - Inspector: Make the object tree resizable.
  - Inspector: Add a "Copy for gitlab" button.
  + Updated translations.
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.17.0 (Unstable):
  + GtkScrolledWindow: Fix criticals in size allocation code
  + GtkFileChooser: Fix a crash in the portal code
  + GtkFontChoser: Make the dialog more shrinkable
  + GtkPicture: Avoid unnecessary resizes
  + GtkVideo: Make dmabufs work without GL
  + GtkListBox: Add a tab-behavior property to influence keynav
  + GtkEmojiChooser: Fix problems with insertion and selection
  + GtkStringList: Add gtk_string_list_find
  + GtkApplication:
  - Respect GDK_DEBUG=no-portals
  - Set default window icon from app ID
  + GtkTextView:
  - Vertical and horizontal positioning of the textview is now
    quantized to the nearest device pixel. This should improve
    the perceived smoothness of scrolling with fractional scaling
    and font hinting.
  - Incorrect re-use of cached styling was fixed
  - Fix some missing CSS invalidation
  - Handle charsets in clipboard datatypes
  + Printing:
  - Avoid warnings for avahi errors
  - Fix a segfault in the print dialog setup code
  + Accessibility:
  - Always realize non-widget accessibles, to help webkit
  - Fix list view selection implementation
  - Handle NULL values in more places
  + Gstreamer: Make dmabufs works without GL
  + Gdk:
  - Add OKLAB and OKLCH color states
  - GL:
    . Drop support for GLES 2 and GL < 3.3
    . Use the ngl dmabuf downloader instead of the GL downloader
  - Vulkan:
    . Drop the GDK_VULKAN_DEVICE env var. Use
    MESA_VK_DEVICE_SELECT instead
    . Use the swapchain maintenance extension to release swap
    images
  - Forbid opening displays before gtk_init()
  + Gsk:
  - Many improvements to the dmabuf downloaders
  - ngl: Avoid glBufferSubData for globals, speeding up llvmpipe
  - Renderer selection will no longer consider the GL renderer
  - Allow Vulkan software rendering as fallback
  - Support gradient interpolation in different color states
  + Wayland:
  - Improve settings portal handling
  - Improve fallback for cursor themes
  - Make cursor theme changes apply immediately
  - Use a viewporter for cursor image scaling
  - Improve cursor size handling
  - Use the system bell protocol if available
  - Fix possible deadlock with high-priority sources triggering
    roundtrips
  + Windows:
  - Improve the backend code
  - Fix some problems with WGL on NVidia
  - Many testsuite fixes for Windows compatibility
  - Make all pixbuf loaders builtin in the gdk-pixbuf subproject
  - Add GDK_DISABLE=aerosnap to disable aerosnap
  - Improve clipboard handling
  - Fix behavior or gdk_display_open() on Windows
  - Numerous papercut fixes
  - Require Windows 10
  + Macos:
  - Fix crashes when dragging libadwaita TabView tabs
  - Require macOS 10.15
  + Tools and demos:
  - gtk4-demo:
    . Make demos standalone
    . Drop GL shader demos
    . Improve scrolling benchmarks
  - gtk4-builder-tool: Improve separator handling
  - gtk4-image-tool: Better color state support
  + Build:
  - Don't set GSK_RENDERER in our flatpaks
  - Require meson 1.2
  + Updated translations.
* Fri Jan  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.12:
  + Switch to the new release process.
- Changes from version 4.16.8:
  + GtkFileChooser: Fix a focus problem with the server entry.
  + GtkEmojiChooser: Update to CLDR 46 / Unicode 16.
  + GtkAboutDialog: Small improvements.
  + Wayland:
  - Fix some Vulkan sizing corner cases.
  - Fix problems with rotated, offloaded images.
  - Fix a few crashes.
  + Demos: Don't create extra windows for D-Bus activation.
* Sun Nov 24 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.7:
  + Text: Reduce the size of error underlines.
  + Accessibility:
  - Fix a wrong return value type.
  - Fix an invalid free call.
* Thu Nov 21 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.6:
  + To prevent issues when using GTK under kwin, this release makes
    Wayland color management opt-in. To experiment with it, set
    GDK_DEBUG=color-mgmt.
  + GtkText: Don't select inserted Emoji
  + GtkApplication: Set the default window icon from the app ID
  + GtkFontChooser: Make the dialog more shrinkable
  + Updated translations.
* Fri Nov  1 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.5:
  + Clean up debug spew.
* Fri Nov  1 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.4:
  + GtkTextView:
  - Fix some missing CSS invalidation
  - Handle charsets in clipboard datatypes
  + GtkApplication: Respect GDK_DEBUG=no-portals
  + Printing:
  - Avoid warnings for avahi errors
  - Fix a segfault in the print dialog setup code
  + Accessibility: Handle NULL values in more places
  + Gdk:
  - vulkan: Fix validation errors
  - Fix 32bit build for the jpeg loader
  + Wayland: Fix a possible deadlock with high-priority sources
    triggering Wayland roundtrips
  + Updated translations.
* Fri Oct  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.3:
  + GtkScrolledWindow: Fix criticals in size allocation code
  + GtkFileChooser: Fix a crash in the portal code
  + GtkPicture: Avoid unnecessary resizes
  + GtkVideo: Make dmabufs work without GL
  + Accessibility: Always realized non-widget accessibles
  + Wayland:
  - Improve settings portal handling
  - Improve fallback for cursor themes
  - Sync default values for settings with schema defaults
  + Updated translations.
* Tue Oct  1 2024 bjorn.lie@gmail.com
- Update to version 4.16.2+10:
  * wayland: Look for default cursor theme in XDG directories
  * wayland: Clear settings_portal when going to fallback with no
    portal settings
  * wayland: Use the same default cursor size as gsettings schema
  * Updated translations.
* Tue Sep 24 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.2:
  + GtkLabel: Fix centered text in RTL
  + Gsk:
  - Speed up some Vulkan operations
  - Improve startup speed by avoiding initialization of GL and
    Vulkan in most cases
  - Reduce critials at startup to warnings
  - Fix a crash on startup with some Vulkan drivers
  - Fix a big texture leak in NGL
  + Gdk: Speed up memory format conversions
  + Wayland: Be more careful with mimetypes during DND or
    copy-paste
  + Tools: builder-tool: Improve conversion of boxes
  + Updated translations.
* Fri Sep 13 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.1:
  + GtkFileChooser: Plug a memory leak
  + GtkCalendar: Avoid ending up with invalid dates
  + Printing: Fix initial printer selection in the print dialog
  + Gsk:
  - Fix shadows for opaque textures
  - Fix a crash in a corner case
  + Css: Make relative paths work again in theme files
  + Accessibility: Fix detection of the Flatpak portal
  + Updated translations.
* Sat Sep  7 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.16.0:
  + Note: This release changes the default GSK renderer to be
    Vulkan, on Wayland. Other platforms still use ngl. The intent
    of this change is to use the best available platform APIs. You
    can still override the renderer choice using the GSK_RENDERER
    environment variable.
  + We believe that most of the problems reported with the new
    renderers during the 4.13 and 4.15 development cycles have been
    addressed by now.
  + But the new renderers and dmabuf support are using graphics
    drivers in different ways than the old gl renderer, and trigger
    new driver bugs. Therefore, it is recommended to use the latest
    mesa release (24.2) with the new renderers.
  + GtkScale: Fix positioning of scale values
  + GtkEmojiChooser: Make Control-clicks work for the recent
    section
  + GtkPopover: Make sure focus lands on the right widget when
    cascading
  + GtkSpinButton: Disable Emoji input for numeric spin buttons
  + GtkSingleSelection: Implement unselect_all
  + Accssibility:
  - Fix roles for radio buttons
  - Check if ATs are listening before exporting trees
  - Add a check for sandboxed accessibility bus
  - Fix handling of the error message relation
  - Turn criticals into debug messages
  - Set expanded states properly in menus
  + CSS:
  - Fix a few issues on bigendian systems
  - Avoid a crash with relative colors
  + GSK:
  - Use the right GL context when exporting textures
  - Don't let colors influence depth decisions
  - Allow uploading of mipmap levels when tiling textures
  + GDK:
  - Update keysyms from libX11 1.8.10
  - Implement cpu-side mipmapping
  - Use a thread pool for color conversions and mipmapping
  + Vulkan: Fix drag surface offsets
  + Wayland:
  - Fix a crash
  - Associate EGL windows with context later
  + X11:
  - Fix initial EGL context creation
  - Fix a problem with GL context creation
  + Broadway: Implement compute_size and request_layout
  + MacOS: Set transparent backgroiund for toplevel windows
  + Windows:
  - Improve debug output
  - Detect Mesas d3d12 driver and request GDI compat
  + Demos:
  - Set window icons in demos
  - Add a 64k x 64k image to the image scaling demo
  + Updated translations.
* Tue Aug 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.15.6:
  + GtkCheckButton: Add a grouped style class for radio buttons
  + GtkScale: Fix alignment and positioning problems
  + Css: Fix crashes in the variable support
  + Gsk:
  - Make graphics offloading work better with kwin
  - Make colorstate transfer functions more robust
  - GC dead textures more agressively
  - Only use a single render pass per frame
  + GL:
  - Round damage rectangles properly
  - Use the shared context when creating textures
  - Fix a file descriptor leak in dmabuf export
  + Vulkan:  Round damage rectangles properly
  + Wayland: Work with the kwin implementation of
    xx-color-management-v4
  + Debugging:
  - Show color state information in the inspector
  - Collect input event traces in the recorder
  - Add shortcuts for toggling recording: Super-r and for
    screenshots: Super-c
  - Split the GDK_DEBUG env var into GDK_DEBUG and GDK_DISABLE
  - Add GDK_DISABLE=color-mgmt and GDK_DISABLE=offload
  + Tools: Add a 'Paste as node' action in gtk4-node-editor
  + Updated translations.
* Wed Aug 21 2024 bjorn.lie@gmail.com
- Update to version 4.15.5+115:
  * gpu:
  - Be more aggressive about GC'ing dead textures
  - The colorstate op doesn't need a colorstates arg
  * win32: Adapt to default flag changes
  * docs: Remove outdated information
  * gdk: Beef up gdk_parse_debug_var
  * egl: Don't bind to NULL surface unless surfaceless
  * wayland: Create EGL window in make_current() if necessary
  * gl: Use the shared GL context when creating GL textures
  * emojichooser: Resize according to screen height
  * GdkWin32: Drop unused variable
  * WGL:
  - Report paint region when presenting (SwapBuffers)
  - Report backbuffer's damage to GDK
  - Search pixel format with defined swap method (opengl32)
  - Search pixel format with defined swap method (arb)
  * Updated translations.
* Thu Aug 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Rebase 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch
  with quilt.
* Mon Aug 12 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.15.5:
  + GtkTextView: ADd GtkTextBufferCommitNotify
  + CSS: Propagate color state information to GSK for many
    features: colors, borders, shadows, text
  + Gdk:
  - Fix an fd leak in the Vulkan code
  - Fix a leak of EGLSurfaces and DMA buffers
  - Set the opaque region of surfaces automatically based on
    their content
  + Gsk:
  - Fix Emoji rendering in Vulkan
  - Rework color handling to take color states into account
  - Implement more powerful occlusion culling
  - Minimize our use of renderpasses
  + Debugging: The inspector shows details about color states
  + Deprecations:
  - gdk_draw_context_begin/end_frame
  - gdk_surface_set_opaque_region
  + Build: Require gstreamer 1.24
  + Updated translations.
- Drop 0002-Revert-no-pointer-viewport.patch: Fixed upstream.
* Fri Aug  2 2024 Joshua Smith <smolsheep@opensuse.org>
- Add 0002-Revert-no-pointer-viewport.patch:
  Fixes https://gitlab.gnome.org/GNOME/gtk/-/issues/6620
* Thu Aug  1 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add missed optflags to CFLAGS.
* Wed Jul 31 2024 Filip Kastl <filip.kastl@suse.com>
- Add -Wno-int-conversion to CFLAGS to enable compilation with
  GCC 14.
* Tue Jul 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.15.4:
  + GtkPopover: Fix size allocation with wrapping labels
  + GtkColumnView: Check column visibility when measuring
  + CSS:
  - Fix fallout from recent changes
  - Make implementation of currentcolor inheritance match browsers
  + Gdk:
  - Introduce GdkColorState for encoding color space information.
    Currently, we support srgb, srgb-linear, rec2100-pq and
    rec2100-linear
  - Add color states to GdkTexture, as well as to the texture
    builder and downloader objects, and convert as necessary
  - Add GdkMemoryTextureBuilder
  - Attach color states when loading or saving textures
  - Add GdkCicpParams to create color state objects for cicp
    tuples
  - Drop GDK_DEBUG=vulkan-validate. Use
    VK_INSTEANCE_LAYERS=VK_LAYER_KHRONOS_validation instead
  + Gsk:
  - Improve caching of glyphs and textures
  - Remove the uber shader
  - Numerous bug fixes
  - Fix corner cases in offload handling
  - Implement occlusion culling for opaque content
  - Allow offloading (some) transformed textures
  - Take colorstate into account when compositing
  - Add GDK_DEBUG=linear to opt into linear compositing
  - Implement tiling for large textures
  - Stop using descriptors and go back to simpler texture
    management that should work better with older GL
  - Use correct shader clip mode for glyphs
  - Improve shadow rendering
  + Media: Attach color states to textures obtained from gstreamer
  + Wayland:
  - Allow offloading GL textures via dmabuf export
  - Suppot the xx-color-management-v4 protocol
  + Deprecations: GskGLShader and the render node
  + Tools:
  - Improve the rendernode tool extract command
  - Add an image tool that is about manipulating textures
  + Build: GTK now requires a C11 compiler
  + Updated translations.
* Mon Jul  1 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.15.3 (bsc#1221052):
  + Accessibility:
  - Only emit notifications when cursor positions change in
    GtkText.
  - Fix handling of help text properties.
  + CSS: Fix some crashes introduced in recent currentcolor
    changes.
  + DND: Avoid a critical.
  + Documentation: Fix many oversights and missing docs.
- Changes from version 4.15.2:
  + GtkFileChooserWidget:
  - Plug some memory leaks.
  - Make Ctrl-Shift-N create a new folder.
  + GtkPopover: Handle resizing and position changes better.
  + CSS:
  - Support color(), oklab().
  - Support color-mix() (https://www.w3.org/TR/css-color-5/).
  - Support relative colors (https://www.w3.org/TR/css-color-5/).
  - Support more colorspaces in color().
  - Allow percentages for opacity.
  - Handle currentcolor more correctly.
  + Accessibility: Avoid markup when reading labels.
  + GSK:
  - Subset fonts when serializing node trees.
  - Make ngl export render_texture results as dmabufs.
  + Wayland: Use xdg-dialog protocol for attached dialogs.
  + Documentation: Widget shortcuts and actions are now described
    in the docs.
  + Debugging: Add GTK_DEBUG=css for warning about deprecated css
    syntax.
  + Tools: rendernode-tool: Add an extract command for data urls.
  + Deprecations:
  - CSS Color functions shade(), lighter(), darker(), alpha(),
    mix().
  + Updated translations.
* Fri Jun 21 2024 joan.torres@suse.com
- Update to version 4.15.1:
  + GtkGraphicsOffload: Don't crash without a child.
  + GtkSpinner: Don't animate when unmapped.
  + CSS:
  - Support the :root selector.
  - Support variables and custom properties.
  - Implement math functions.
  - Support modern syntax and calc in rgb() and hsl().
  + Icontheme:
  - Make symbolic svg loading more efficient.
  - Handle color-free symbolics more efficiently.
  + Accessibility:
  - Make the gtk-demo sidebar search more accessible.
  - Stop emitting focus events.
  - Realize child contexts when necessary.
  + GDK:
  - Support XDG_ACTIVATION_TOKEN.
  - dmabuf: Be more defensive when importing unknown formats to
    GL.
  - dmabuf: Use narrow range for YUV.
  - vulkan: Recreate swapchains when necessary or beneficial.
  + GSK:
  - Improve logging for GDK_DEBUG=offload.
  - Improve logging for GSK_DEBUG=renderer.
  - gpu: Warn about inefficient texture import.
  - gpu: Handle tiny offscreens correctly.
  - vulkan: Add profiler marks in various places.
  - vulkan: Fix a problem with imported dmabufs showing up black.
  - cairo: Speed up mask nodes, since we use them for symbolic
    icons.
  + Wayland: Use wl_compositor version 6.
  + X11: Implement a missing method.
  + Build: Fix many ubsan warnings.
  + Debugging:
  - Show more texture details in the recorder.
  - Use GTK_DEBUG=css to see CSS deprecations.
  + Deprecations: Use of @name colors in CSS.
  + Updated translations.
* Fri May  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.14.4:
  + GtkGraphicsOffload: Don't crash without a child.
  + Icontheme:
  - Make symbolic svg loading more efficient.
  - Handle color-free symbolics more efficiently.
  + Accessibility:
  - Make the gtk-demo sidebar search more accessible.
  - Stop emitting focus events.
  + GDK:
  - Support XDG_ACTIVATION_TOKEN.
  - dmabuf: Be more defensive when importing unknown formats.
  - dmabuf: Use narrow range for YUV.
  + GSK: gpu: Handle  tiny offscreens correctl.
  + Build: Fix many ubsan warning.
  + Updated translations.
* Fri Apr 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.14.3:
  + GtkShortcutManager: Track the propagation phase of added
    controllers.
  + Accessibility: Implement GtkAccessibleRange for scrollbars.
  + X11:
  - Fix some confusing debug messages
  - Drop a no-longer-relevant optimization that was interfering
    with getting the current window manager capabilities.
  + Tools: Support generating pdf in gtk4-rendernode-tool.
  + Updated translations.
* Thu Apr  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.14.2:
  + GtkScale: Improve positioning of values in some cases.
  + Theme: Make progress in entries visible.
  + Accessibility: Fix text insertion handling.
  + GDK:
  - dnd: Use the default cursor durion motion
  - dnd: Use a better cursor for indicating the move action
  + GSK:
  - gl: Handle offloads in offscreen context better
  - Fix text rendering problems with some fonts
  + Wayland:
  - Tighten up some protocol version checks
  - Use the presentation time protocol
  - Fix a crash with subsurfaces
  - Improve settings portal handling
  + Debugging: Add font settings in the inspector.
  + Demos:
  - Clean up the application demo
  - Update cursor images for the cursor demo
  + Updated translations.
* Sun Mar 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.14.1:
  + GtkTextView: Fix a mixup of cursor and anchor when retrieving
    surrounding text in input methods.
  + Printing: Avoid accessing freed printers.
  + Accessibility: Fix memory leaks.
  + GDK:
  - Rename the GDK_VULKAN_SKIP environment variable to
    GDK_VULKAN_DISABLE.
  - Add a GDK_GL_DISABLE environment variable.
  + GSK:
  - Rename the GSK_GPU_SKIP environment variable to
    GSK_GPU_DISABLE.
  - Speed up handling of repeated ops, which should help for
    text.
  - Speed up the inner loop of text node conversion.
  - Drop the glyph-align optimization flag.
  - ngl: Avoid reusing frames while they are in use.
  - Fix flickering thumbnails in nautilus.
  - Speed up buffer handling in both ngl and Vulkan.
  + Demos: Skip demos using gl shaders when we're not using the gl
    renderer.
  + Build:
  - Fix some ubsan warnings.
  - Avoid zink in ci since it spams stderr.
  + Updated translations.
* Tue Mar 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.14.0:
  + GtkTextView:
  - Don't snapshot children twice.
  - Don't blink the cursor when hidden.
  + GtkEmojiChooser: Fix presentation selector handling.
  + GtkSnapshot: Fix wrong nodes with transformed shadows.
  + GtkIMContext: Make gtk_im_context_activate_osk public.
  + Accessibility:
  - Implement get_contents_at for all our text widgets.
  - Add GtkAccessibleText.get_default_attributes.
  + GSK:
  - Don't fall back to cairo for software rendering. gl+llvmpipe
    is better.
  - Round vertical glyph position to a device pixel position if
    the font is hinted.
  - Fix problems with clip handling.
  - Make vulkan and ngl match their font handling.
  - Fix some corner-cases with offloading and clips.
  - Fix problem with rendering of missing glyphs in hinted fonts.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.13.9:
  + GtkEditable: Fix preconditions to be not too strict.
  + GtkEmojiChooser: Support search in the locale as well as in
    English.
  + GtkIconTheme: Make gtk_icon_paintable_new_for_file support
    symbolics.
  + GtkVideo: Fix a problem with cursor handling that could lead to
    crashes.
  + Accessibility:
  - Fix GetCharacterAtOffset implementation.
  - Add a Terminal role.
  - Make TextCaretMoved match gtk3.
  - Support multiple levels of GtkEditable delegates.
  + GSK:
  - Make the node parser more flexible for text nodes.
  - Change the way font scaling is handled to avoid clipping.
  - Fix handling of missing glyphs in the new renderers.
  + X11: Don't claim to support shadows without a compositor.
  + Wayland: Fix handling of output scales.
  + Tools: Add a compare command to gtk4-rendernode-tool.
  + Build: Fix some ubsan complaints.
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.13.8.1+7:
  + Fix Crash in gtk_file_dialog_save() with initial filename.
  + x11: Shadows require compositing
* Wed Feb 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.13.8:
  + Accessibility:
  - Add a GtkAccessibleText interface for allowing 3rd party.
    text widgets (notably vte) to be accessible.
  - Avoid duplicate accessible descriptions.
  - Fix GetAccessibleAtPoint.
  + GSK:
  - Avoid offscreens for disjoint containers.
  - Don't use the gpu renderers with llvmpipe.
  - Fix various rendering issues found by tests.
  - Allow unnormalized node bounds again.
  - Fix a broken case of rounded-rect intersection.
  - Fix handling of external textures in gpu renderers.
  - Make gpu renderers work with WGL on Windows.
  + build: Allow building without dmabuf support on (old) Linux.
  + X11: Fix monitor enter/leave signals.
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.13.7:
  + GtkFileChooser: Speed up opening.
  + GtkCalendar: Add some missing setters and getters.
  + Accessibility:
  - Add socket support for webkit accessibility.
  - Implement AT-SPI text for GtkText.
  - Implement AT-SPI component generically.
  - Add an announce API.
  + GSK:
  - Fix a crash in the vulkan renderer.
  - Make nodeparser allow aliases for fonts again.
  - Implement cache eviction for glyph and texture caches.
  - Fix ngl shaders to work on GL < 4.0.
  - Require GL 3.3 for the ngl renderer.
  - Fix problems with scaled shadows.
  - Fix problems with holes for underlaid subsurfaces.
  - Improve handling of scales and glyph cache efficiency.
  + Media:
  - Support dmabufs in the gstreamer backend. This allows
    zero-copy video playback on Wayland when paired with
    hardware video decoding.
  - Drop the experimental ffmpeg backend. It hasn't been
    building for a year.
  + Wayland:
  - Commit empty frames if and double-buffered state is pending.
  - Fix monitor size information when using mutter without
    the scale-monitor-framebuffer setting.
  - Clear the current tablet on tab leave, fixing a crash.
  + Tools: Make the crash handling in gtk4-node-editor more robust.
  + Updated translations.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.13.6:
  + GtkColumnView:
  - Fix infinite loops in dispose.
  - Fix problems with weak ref cycles in GtkExpression.
  + GtkListView:
  - Fix some corner cases with sections during insertions and
    deletions.
  - Don't double-recycle widgets.
  + GtkStack: Add automatic cleanup for GtkStackPage.
  + GDK:
  - Use standard cursor names for drag cursors.
  - Enable fractional scaling with gl by default.
  + GSK:
  - Many fixes and improvements to the unified renderers:
  - Fix text rendering with the uber shader.
  - Fix rounding issues with fractional scales.
  - Fix some memory leaks.
  - Many text rendering fixes.
  - Implement subpixel positioning for glyphs.
  - Support custom fonts in node files.
  - Add tests for font rendering.
  - Fix drawing of repeat nodes.
  - Implement subpixels positioning.
  - Evict stale textures, glyphs and atlases from the cache.
  - Some fixes and improvements to the GL renderer:
  - Fix problems with GLES on Nvidia.
  - Avoid a crash in the mask demo.
  - Respect opacity of the first child node in containers.
  - Some fixes and improvements to the fallback renderer:
  - Fix drawing of repeat nodes.
  - Make ngl the default renderer.
  + Wayland:
  - Fix problems with tablet cursors.
  - Fix problems without seats.
  + Accessibility:
  - Respect a separate "show-status-shapes setting.
  - Fix change notification for accessible names on some widgets.
  + Inspector: Show the git commit in devel builds.
  + Tools:
  - Make gtk4-node-editor autosave its contents.
  - Add a benchmark command to gtk4-rendernode-tool.
  + Updated translations.
- Changes from version 4.13.5:
  + This release adds two new GSK renderers called vulkan and ngl,
    that are built from the same sources. The new renderers can
    handle many corner cases correctly that the current gl renderer
    does not handle, and they offer advantages such as antialiasing
    and supersampled gradients.
  + GtkDropdown: Fix display of initial selection
  + GtkShortcutsWindow: Make the window adapt to smaller screen
    widths
  + GtkTextView: Fix a possible NULL dereference in history
  + GDK: Make the png loader safer against overflows
  + GL: Fix some errors in handling of texture formats and mipmaps
- Switch to source-service managed sources.
- Enable sassc BuildRequires, as we're now building from git.
- Enable pkgconfig(vulkan) BuildRequires: upstream recommends
  enabling vulkan by now.
- Add shaderc BuildRequires: new dependency for the vulkan
  renderer.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.12.5:
  + GtkColumnView: Fix a crash on dispose.
  + GtkEmojiChooser:
  - Update to CLDR v44.
  - Add more translations.
  + GtkFileDialog:
  - Return an error if no file is selected.
  - Make closing the portal file chooser work.
  + GtkDropDown: Fix display of the initial checkmark.
  + GtkShortcutsWindow: Reduce the minimum width.
  + GDK: Make the png loader safer against overflow.
  + Wayland: Fix cursor handling with graphics tablets.
* Fri Dec  1 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.12.4:
  + a11y: Tweak name computation for some corner cases.
  + gdk:
  - gl: Improve our use of GLES a bit (use vertex arrays and
    GL_BGRA if available)
  - Fix some errors in our memory format tables
  + gsk:
  - gl: handle texture-scale nodes more faithfully
  - gl: Fix icon padding in the atlas
  + Tools: Add a --undecorated option to gtk4-rendernode-tool.
  + Updated translations.
* Thu Sep 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.12.3:
  + GtkWindow: Don't assume titlebars are GtkHeaderBar
  + GtkTreeView: Fix a crash in gtk_tree_view_is_blank_at_pos
  + printing: Fix some issues with the portal implementation
  + GSK:
  - Some optimizations in the GL renderer
  - Fix memory leaks in the Broadway renderer
  + demos: Fix a crash in gtk4-demo
  + Updated translations.
* Wed Sep 20 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 4.12.2:
  + GtkTooltip: Don't cross native boundaries when looking for
    tooltips.
  + GtkCenterLayout, GtkEntry, GtkSearchEntry: Fix some issues with
    baseline handling.
  + GtkSwitch: Respect text direction.
  + Theme: Use relative font sizes.
  + GSK:
  - Make repeated gradients match between GL and cairo.
  - Make rounded rect shrinking match between Vulkan, GL and
    cairo.
  - Fix parsing of text nodes with color glyphs.
  - Restrict an optimization to the cases where it is correct.
  - Fix rendering of shadows with opacity.
  + Updated translations.
- Drop merged upstream patch: e001b421.patch.
* Wed Sep 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add e001b421.patch: tooltip: don't cross native boundaries.
* Thu Aug 31 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Re-add 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch
  and rebased/simplified (less correct, but sufficient for us)  for
  4.12.1.
* Fri Aug 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.12.1:
  + GtkGridView: Fix a crash when scrolling
  + GtkColumnView: Fix a refcounting issue in the new scroll_to api
  + GtkTreeView: Fix style classes for sort arrows
  + GtkEntry: Improve tracking of user changes (for undo)
  + GtkNotebook: Fix a critical when switching pages
  + GtkColor/FontDialogButton: Make these widgets activatable
  + GtkMenuButton:
  - Fix problems with focus handling
  - Fix problems with DND
  + Printing: Fix the cpdb backend build
  + GSK: Fix issues with color matrix nodes
  + Wayland: Fix a crash with compositors other than gnome-shell
  + Updated translations.
- Drop patches fixed upstream:
  + 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch
  + 6af9dc86.patch
* Mon Aug 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 6af9dc86.patch: print: Revert "Start sorting apart includes"
  change for gtkprinteroptionprivate.h.
* Mon Aug  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.12.0:
  + List widgets: Add scroll_to APIs
  + GtkFileLauncher: Add an always-ask property
  + GtkTextView: Make backspace behavior match GtkEntry
  + gsk: Fix handling of luminance in mask nodes
  + Text rendering: Automate the setting of gtk-hint-font-metrics
    from the scale factor. This improves font rendering in flatpaks
  + Wayland:
  - Fix behavior of stylus buttons
  - Support suspended window state
  + Vulkan: Many improvements
  + Tools: Add gtk4-rendernode-tool
  + Debugging: Drop the GTK_DEBUG_TOUCHSCREEN flag
  + Build: Some build options have been renamed:
  - gtk_doc -> documentation
  - update_screenshots -> screenshots
  - The old names still work
  + Updated translations.
- Update option passed to meson following upstream changes.
* Sun Aug  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.11.4:
  + GtkFileChooser:
  - Default to sorting folders first
  - Fix a crash when visiting recent files
  + GtkTextView: Fix corner cases in word navigation
  + GtkMenuButton: Normalize label layout
  + GtkDropDown: Add support for sections
  + GtkVideo: Make the overlay icon clickable
  + GtkWindow: Clear the resize cursors to avoid artifacts
  + GtkFileDialog: Always set initial-folder
  + GtkDropDown: Update on expression changes
  + GtkMapListModel: Implement GtkSectionModel
  + Accessibility:
  - Improvements all over the place: GtkButton, GtkPasswordEntry,
    GtkFontChooserDialog, GtkColorChooserDialog,
    GtkShortcutsWindow, GtkMenuButton, GtkAboutDialog,
    GtkFileChooserDialog, GtkStackSidebar, GtkStackSwitcher,
    GtkMediaControls, GtkColorDialogButton, GtkDropDown,
    GtkInfoBar, GtkNotebook, GtkPrintUnixDialog, GtkModelButton
  - Make name computation follow the ARIA spec more closely
  - Adapt name computation for the common 'nested button'
    scenario
  - Change many containers to use `generic` instead of `group`
  - Use `generic` as the default role
  - Use `application` instead of `window` for windows
  - Add properties for accessible names of not directly exposed
    widgets in GtkListView, GtkGridView and GtkColumnView
  + DND: Fix criticals when drops are rejected
  + X11: Fix regressions in GLX setup
  + Windows: Center newly created transient windows
  + Vulkan:
  - Add antialising for gradients
  - Do less work on clipped away nodes
  - Redo image uploading
  - Support different image depths and formats
  - Add a pipeline cache
  + Demos:
  - gtk4-demo: Improve window sizing
  - gtk4-demo: Improve focus behavior
  - gtk4-demo: Add many missing a11y properties
  + Tools: gtk4-builder-tool: Make render an alias screenshot
  + Inspector:
  - Show more information in the a11y tab
  - Add an accessibility overlay with warnings and
    recommendations
  - Limit the width of the a11y tab
  + Build:
  - Require GLib 2.76
  - Make asan builds work again
  - Fix the build if ld is not ld.bdf
  + Updated translations.
* Sat Aug  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.5:
  + Fix ordering problems with filter model signals
  + Avoid lingering resize cursors
  + Fix alignment issues on sparc
  + Fix a problem with CSS corner values
  + Updated translations.
* Mon Jun  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.4:
  + GtkFileChooser: Fix some memory leaks
  + GtkUriLauncher: Validate the uri
  + GtkStack: Fix a crash
  + GtkGridView: Respect css border-spacing
  + GtkScrolledWindow: Propagate child measure size whenever
    possible
  + GtkPopoverMenu: Avoid unnecessary left padding
  + GtkSearchEntry: Improve size allocation for the clear icon
  + X11:
  - Avoid black flickering with xwayland window decorations
  - Trap XRandr errors
  + CSS: Various fixes to transitions
  + Updated translations.
- Drop patches fixed upstream:
  + fix-gridview.patch
  + gtk4-correctly-refresh-after-delete.patch
  + 966a2350.patch
* Sun Jun  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Add fix-gridview.patch: Add border-spacing where it was missed.
  We were computing column widths without taking border-spacing into
  account, making them slightly too big (glgo#GNOME/nautilus#2980).
* Thu May  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 966a2350.patch: css: Don't transition to currentColor.
  Transition to the color that is in use instead. Fixes crashes
  because currentColor is not an RGBA color and therefor could not
  be queried later (glgo#GNOME/gtk#5798).
* Wed May  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add gtk4-correctly-refresh-after-delete.patch -- Fix issue where
  deleting files causes folders in the directory to disappear and
  reappear after a refresh (glgo#GNOME/nautilus#2941); patch taken
  from upstream commit.
* Thu Apr 27 2023 Frederic Crozat <fcrozat@suse.com>
- Do not build media playback when bootstrapping on Workbench.
* Sat Apr 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.3:
  + Fix a popover positioning regression in 4.10.2.
  + Fix issues with slow loading files in the file chooser.
* Fri Apr 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.2:
  + Holding control to select multiple files broken in filechooser
  + Inspector crash
  + Listbase doesn't account for bottom padding in
    size_allocate_child
  + Leaking AT contexts
  + OpenGL / Windows: Crash when closing gtk4-widget-factory
  + GTK apps crash on startup when setting cursor-size to 0 on
    Wayland
  + Segmentation fault: gdk_wayland_toplevel_set_startup_id() needs
    to null-check display->xdg_activation before using it
  + Possible use-after-free under
    gtk_scrolled_window_update_use_indicators()
  + Wrong error message in `gtk_init`
  + Segfault when scrolling after changing ListView model
  + Bluetooth panel from the Settings app: clicking in the
    "Downloads" link no longer opens Nautilus
  + Broadway docs or code is broken
  + Disabled GtkPicture's are not properly themed
  + Setting CSS padding to a GtkTextView gives the context menu an
    offset
  + A11y: the Showing state is used only for windows
  + Gtk4 expander: CSS nodes mismatch code vs. documentation
  + Invoking gtk inspector on a folder results in a crash
  + Double tap requires very precise touch input
  + Name autocompletion dropdown in the GTK4 FileChooser's Save
    dialog gets stuck, creates artifacts, jumps around
  + Links are not opened when xdg-desktop-portal OpenURI is not
    available
  + GtkSnapshot generates no nodes appending whitespace-only
    layouts
  + Updated translations.
* Wed Apr 12 2023 Luciano Santos <luc14n0@opensuse.org>
- Place English translations in the tools sub-package instead of
  lang. This should offer translations for the main English locales
  without the need to install any additional package by default.
- Add "file-not-in-%%lang" RPM Lint warning to rpmlintrc file for
  the reason above.
- Drop "shlib-policy-name-error" unused filter from rpmlintrc.
* Sun Apr  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Disable vulkan support, stop passing vulkan=enabled to meson.
  Disable vulkan-devel Requires and BuildRequires.
- Disable pkgconfig(libavfilter) BuildRequires, upstream do not
  enable ffmpeg support by default and we do not enable it, so no
  need to carry the dependency.
- Use ldconfig_scriptlets macro.
- Pass build-testsuite=false, build-tests=false and
  build-examples=false to meson, no longer build these as we are
  not running or installing them anyway, save a lot on buildtime.
* Tue Mar 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.1:
  + GtkFileChooser:
  - Improve search performance
  - Be safe against pathless files
  - Fix memory leaks
  - Only show local files in recent files
  - Show most recent files first
  - Make files non-selectable in selet_folder mode
  + GtkListView / GtkColumnView / GtkGridView:
  - Fix scrolling problems
  - Support CSS border-spacing
  + GtkComboBox: Fix a size allocation problem
  + gtk: Size allocation fixes
  + Accessibility: Miscellaneous property fixes and improvements
  + Wayland: Fix an ordering problem in surface disposal
  + Windows: Fix Visual Studio build with older GLib
  + Updated translations.
- Drop patches fixed upstream:
  + 3e3158ce12741b58ce53f132b48f26438094886d.patch
  + 0001-combobox-Avoid-extra-queue_resize.patch
- Refresh 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch
  with quilt.
* Fri Mar 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 3e3158ce12741b58ce53f132b48f26438094886d.patch: widget: Use
  the correct template in dispose_template(). Fixes crashes in
  various apps.
- Refresh patches with quilt.
* Thu Mar  9 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add 0001-combobox-Avoid-extra-queue_resize.patch: Fix combobox
  not showing (bsc#1209043 glgo#GNOME/gtk!5608).
* Sun Mar  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.10.0:
  + GtkTextView: Document hanging indentation
  + GtkListView: Fix a size allocation problem
  + GtkFileChooser:
  - Fix paned behavior
  - Fix a crash
  + GtkText: Fix various problems with undo
  + Accessibility:
  - Make some getters transfer-full
  - Allow setting accessible parents and siblings
  - Add a role for toggle buttons
  - Miscellaneous property fixes and improvements
  + gtk: Improve the handling resize-during-size-allocate
  + gdk:
  - Introduce GdkTextureDownloader and use it
  - Make gdk_texture_get_format public
  + gsk:
  - Make mask nodes more versatile
  - Improve the GL implementation for texture scale nodes
  + X11: Fix key handling during DND
  + Tools:
  - gtk-builder-tool: Try harder to handle templates
  - gtk-builder-tool: Prefer properties over <child>
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.9.4:
  + Printing:
  - Add a CPDB backend
  - Drop the lpr backend
  + GtkFileDialog: Robustness fixes
  + GtkScaleButton: Add an 'active' property
  + GtkSearchEntry: Add placeholder text
  + Fix conflicting type names between gtk and gio
  + Gsk:
  - Settable filtering for scaled textures
  - Add mask nodes
  - Some robustness and crash fixes
  + Wayland: Handle dispatch failing in more places
  + Deprecations: GtkVolumeButton
  + Updated translations.
- Changes from version 4.9.3:
  + Add GtkUriLauncher, as replacement for gtk_show_uri
  + Add GdkMonitor::description
  + Fix problems with tooltip sizing
  + Deprecations:
  - GtkStatusbar
  - GtkAssistant
  - GtkLockButton
  - gtk_gesture_set_sequence_state
  + GtkColumnView: Only create widgets for visible columns
  + GtkFileDialog: Drop shortcut folders API
  + GtkCalendar: Make marked days work again
  + GtkSwitch: Make state and active independently settable
  + GtkFileChooser:
  - Fix a crash with DND
  - Fix excessively wide sidebar
  - Make context menus work again
  + Accessibility:
  - Make GtkAccessible public, so it can be implemented outside
    GTK
  - Support accessible implementation for editables
  + CSS: Fix randomly stopping CSS animations
  + GL:
  - Fix synchronization with GStreamer
  - Fix problems with 3rd party GL in the same thread
  + Wayland: Fix startup notification with xdg_activation
  + Broadway: Implement modal windows
  + macOS: Make DND work
  + Build:
  - Require graphene 1.10
  - Require gobject-introspection 1.72
  + Updated translations.
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.9.2:
  + GtkFileChooserWidget: Add a grid view.
  + GtkText, GtkTextView:
  - Fix activation of the on-screen keyboard.
  - Prevent unexpected text direction changes.
  + GtkCenterBox: Add properties for children.
  + GtkTreeExpander: Add a hide-expander property.
  + GtkStringList: Add a construct-only strings property.
  + GtkBuilder: Support parsing Pango attributes in string form.
  + GtkGestureStylus: Add a stylus-only property.
  + GtkFileLauncher: New async-style api to replace gtk_show_uri.
  + GtkColorDialog, GtkFontDialog, GtkFileDialog, GtkAlertDialog:
  - APIs have seen some tweaks
  - Prefer portals when available
  - Fixes for cancellation
  + Add GDK_DEBUG=no-portals
  + Improve file DND with remote files
  + GtkInfoBar has been deprecated
  + gtk_widget_show/hide have been deprecated
  + gtk_show_uri has been deprecated
  + Wayland:
  - Fix button mask handling
  - Fix problems with cursor size on hi-dpi screens
  - Support newer versions of some protocols
  - Fix handling of surrounding text in input methods
- Changes from version 4.9.1:
  + GtkTreeView, GtkIconView, GtkComboBox and auxiliary classes
    have been deprecated.
  + GtkEntryCompletion has been deprecated.
  + GtkStyleContext has been deprecated.
  + gtk_render_ and gtk_snapshot_render_ APIs have been deprecated.
  + GtkAppChooser widgets have been deprecated.
  + GtkMessageDialog has been deprecated and replaced by a new
    async dialog API.
  + GtkDialog has been deprecated.
  + GtkColorChooser, GtkFontChooser, GtkFileChooser interfaces and
    their implementations have been deprecated. A new family of
    async dialog APIs has been introduced to replace them.
  + GtkColorDialog, GtkFontDialog, GtkFileDialog and GtkAlertDialog
    are new dialog classes with a consistent and well-bindable API.
  + GtkMountOperation:
  - Fix the dialog to look reasonable.
  - Make it work under non-X11.
  + GtkStringSorter: Support different collation methods.
  + Accessibility: Introduce GtkAccessibleRange and implement it.
  + Debugging:
  - Unify formatting for debug output.
  - Make make debug options available in non-debug builds.
  + Increase the memory limit for the jpeg loader to 1G.
* Thu Dec 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.3:
  + GtkText:
  - Claim gestures more selectively.
  - Prevent unexpected notify::direction emissions.
  + Accessibility: Remember if we don't find the a11y bus.
  + DND: Prefer file:// urls over other protocols.
  + GtkMountOperation: Work on Wayland.
  + GtkListView: Cancel rubberband if not handling drag.
  + Wayland: Fix button masks.
  + Windows: Fix resizes with native decorations.
  + X11: Fix some ordering problems with surface destruction.
  + Updated translations.
* Fri Nov 11 2022 Daike Yu <yu.daike@suse.com>
- Update gtk4.spec to align dependency version with meson.build
* Mon Oct 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.2:
  + Input:
  - Give input methods more control over resets and allow them to
    preserve state.
  - Align interpretation of modifiers in key events in X11 and
    Wayland.
  + GtkColumnView: Fixes to focus handling.
  + GtkPopover:
  - Fix problems with focus when dismissing popovers.
  - Fix problems with focusing editable labels in popovers.
  + Build:
  - Fix build problems with resources and non-gnu linkers.
  - Fix gi-docgen detection in cross builds.
  - Require meson 0.60.
  + Debugging:
  - Make more debug options available in no-debug builds.
  - Improve consistency of debug logging.
  - Give names to all sources.
  + Accessibility: Introduce GtkAccessibleRange.
  + Wayland:
  - Make monitor bounds handling more robust.
  - Prevent shrinking clients due to wrong toplevel bounds.
  + Broadway: Return correct pointer coordinates from device
    queries.
  + Updated translations.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.1:
  + Input:
  - Fix problems with input method interactions that caused dead
    keys not to work.
  - Accept single-key compose sequences (these are used with some
    keyboard layouts).
  + GtkColumnView: Flip column order in right-to-left context.
  + GtkGridView: Fix problems with rubberbanding.
  + GtkFileChooser:
  - Fix positioning of popovers in the places view.
  - Make ~ and . keyboard shortcuts work again.
  + gsk: Make glyph upload more similar to icons.
  + Make file transfer via portals work, this fixes file copy/paste
    and dnd in flatpaks.
  + Updated translations.
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.8.0:
  + GtkTreeView:
  - Fix a problem with scrolling animations
  - Fix some event handling problems
  - Drop unreachable code
  + GtkText: Respect the no-emoji input hint fully
  + GtkEmojiChooser: Fix arrow key navigation
  + GtkFontChooser: Improve the handling of OpenType font features
  + GtkTreeListModel: Fix handling of collapsed child nodes
  + GtkInscription: Fix accessible name
  + Theme: Fix placeholder text in HighContrast
  + Increase the memory limit for the jpeg loader to 300M
  + Miscellaneous memory leak fixes
  + Wayland: Refator handling of text protocol client updates
  + Updated translations.
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(rest-0.7) BuildRequires: it seems to serve no
  purpose, nor can I find anything to suggest that gtk depends on
  it.
* Thu Aug 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.7.2:
  + GtkTextView: Fix child positioning with gutters.
  + GtkText: Update placeholder visibility when necessary.
  + GtkPicture: Add a content-fit property.
  + GtkPopover: Fix a size allocation problem with the arrow.
  + GtkTreeView: Fix a problem with DND.
  + GtkTreePopover: Support scrolling.
  + GtkGridView: Fix issues with rubberband selection.
  + GtkLabel: Add a tabs property.
  + GtkSnapshot: Make GtkSnapshot work from bindings.
  + GtkScrolledWindow: Scroll at a reasonable speed.
  + GtkPaned: Avoid an infinite loop.
  + GtkWindow: Improve generation and handling of crossing events.
  + CSS: Fix handling of certain transform values.
  + Media support:
  - Add audio support to the ffmpeg backend.
  - Avoid oom with pathological jpeg images.
  + GDK:
  - Fix handling of touchpad hold events.
  - Add support for hi-resolution scroll events.
  + X11: Fix preferred action for DND.
  + List models:
  - Fix items-changed emission.
  - Add more list model tests.
  + Demos:
  - Add a winning sound to game demos.
  - Make app icons work uninstalled.
  + Updated translations.
* Sat Aug  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 0001-Revert-Meson-Simplify-pkgconfig-file-generator.patch:
  Revert "Meson: Simplify pkgconfig file generator". Temporarily
  revert this until we figure out how to best restore private
  requires that are needed for rpm automatic dep extraction.
  https://gitlab.gnome.org/GNOME/gtk/-/merge_requests/4756
  This reverts commit 802bf4199911c811938b0454a876089bafa97dba.
* Wed Aug  3 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.7.1:
  + GtkInscription: A new label-like widget for use in list views.
  + GtkColorChooser: Style improvements.
  + GtkFontChooser: Improve support for OpenType features a bit.
  + GtkLabel: Allow selectable labels to be activated via mnemonic.
  + GtkTextView: Implement GetCharacterExtents for accessibility.
  + GtkStack: Fix a poblem with stack page accessibility.
  + GtkListView:
  - Cull listitems that are out of view.
  - Make all our list models implement ::n-items and
    ::item-type properties.
  + Translations:
  - Stop translating property nicks and blurbs.
  - Fix extracting translations from ui files.
  + Debugging:
  - Support GTK_DEBUG=invert-text-dir.
  - Allow inspecting inspectors.
  - Replace GTK_USE_PORTAL with GDK_DEBUG=portals.
  - Improve responsiveness of the inspector.
  + CSS: Allow fractional letterspacing.
  + Theme: Improve legibility of selectable labels.
  + Demos:
  - Improve the font features demo.
  - Add demos for GtkInscription.
  + Wayland:
  - Freeze popups when hidden.
  - Only send smooth scroll events for tablet tools.
  - Make scaled cursor image have the right size.
  - Fix problems with the activation protocol.
  - Don't force the HighContrast icon theme.
  - Support xdg_toplevel.bounds.
  + X11: Always update the shadoe size.
  + Windows:
  - Improve touchpad support by using DirectManipulation.
  - Add more directories to the builtin hicolor icon theme.
  + Updated translations.
- Add pkgconfig(harfbuzz) BuildRequires: new dependency.
* Mon Jul  4 2022 Yifan Jiang <yfjiang@suse.com>
- Add compatible dependency "python3-gobject-Gdk if python3-gobject"
  to the typelib package for SLE and Leap (boo#1200614).
* Fri Jun 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add dependency "python3x-gobject-Gdk if python3x-gobject" to the
  typelib package (boo#1200614).
* Wed Jun  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.7.0:
  + GtkTextView: Reduce overdraws.
  + GtkViewport: Default scroll-to-focus to TRUE.
  + GtkText: Stop blinking when we lose focus.
  + GtkSearchEntry: Make search delay configurable.
  + GtkPopoverMenu: Fix RTL positioning of buttons.
  + GtkLabel: Fix focus keynav with links
  + GtkFileChooser:
  - Prevent undesirable completion popups.
  - Fix a corner case in save mode.
  - Keep the portal filechooser alive long enough.
  + GtkCheckButton: Allow setting a custom child.
  + GtkEditableLabel: Make the :editing property writable.
  + GtkColumnView: Various optimizations to improve scrolling
    performance.
  + GtkTreeStore: Allow populating tree stores from ui files.
  + GtkBoxLayout: Avoid infinite loops.
  + CSS: Optimize reordering within the same parent.
  + Emoji:
  - Update to CLDR v40 / Unicode 14.
  - Add more locales.
  + Input:
  - Add scroll unit handling.
  - Handle display changes in GtkIMMultiContext.
  - Always populate GDK_AXIS_X/Y in event history.
  - Don't crash for large compose tables.
  + Accessibility: Fix a crash at start when orca is running.
  + Theme:
  - Refresh icons.
  - Fix selection in vertical spin buttons.
  - Fix selection in editable labels.
  + gdk:
  - Optimize pixel format conversions.
  - Use EGL_KHR_swap_buffers_with_damage for NVidia.
  + gsk:
  - Handle large viewports.
  - Prepare texture libraries for glyphy rendering.
  - Don't leak big glyphs in the glyph cache.
  - Align offscreen rendering with th pixel grid.
  - Check for half-float support before using it.
  + Updated translations.
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.6.5:
  + GtkFileChooser: Fix pasting text into the name field.
  + GtkText: Remove an assertion that is sometimes hit.
  + Wayland: Ensure that our cursor surfaces don't violate protocol
    constraints.
  + Accssibility: Fix a problem in the accessibility tree.
  + Updated translations.
* Fri May 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.4:
  + GtkFileChooser:
  - Fix select button sensitivity in select_folder mode.
  - Fix some fallout from list model porting.
  + GtkListView, GtkColumnView: Optimize scrolling.
  + print-to-file:  Handle nonexisting files better in the dialog.
  + Avoid infinite loops in size allocation.
  + CSS:  Optimize a case of reparenting that is important in
    GtkListView.
  + GSK: Check for half-float support before using it.
  + Wayland:
  - Ignore empty preedit updates This fixes a problem with
    textview scrolling.
  - Freeze popups when hidden. This addresses a frame rate drop-
  + Updated translations.
* Thu Apr 28 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.6.3:
  + GtkOverlay: Bring back positional style classes.
  + GtkFileChooser:
  - Prevent unwanted completion popups.
  - Fix small problems in save mode.
  - Fix buildable suport of GtkFileFilter.
  + GtkPopover: Fix button positions in right-to-left locales.
  + GtkLabel: Fix small issues with link handling.
  + Tooltips: Don't restrict the minimum tooltip length.
  + Theme:
  - Don't use opacity for overlay scrollbars.
  - Fix selection text color in  vertical spin buttons.
  + GSK:
  - Accept textures that are generated by webkit.
  - Align offscreen rendering to the pixel grid.
  + Accessibility: Fix a crash in startup when orca is running.
  + Input:
  - Fix display changes in GtkIMMultiContext.
  - Fix activating on-screen keyboards.
  - Always propagate hold events in GtkEventControllerScroll.
  + Windows:
  - Fix a critical warning in clipboard handling.
  - Report serial numbers for events.
  + MacOS: Prevent fullscreen transition reentrancy.
  + Updated translations.
- Drop gtkimmulticontext-Handle-switches-between-displays.patch:
  fixed upstream.
* Thu Mar 31 2022 Jeff Mahoney <jeffm@suse.com>
- gtkimmulticontext: Handle switches between displays
  (glgo#GNOME/gtk#4805). Added:
  gtkimmulticontext-Handle-switches-between-displays.patch
* Thu Mar 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Split tools package into tools and devel-tools, place the tools
  that are mainly of interest to developers into the latter.
* Thu Mar 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Move various binaries and resources from devel to tools
  subpackage.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.2:
  + GtkScrolledWindow:
  - Set scroll-to-focus on viewports
  - Avoid doubly triggering deceleration
  + GtkEntry: Stop cursor blinking on focus-out
  + Emoji:
  - Update Emoji data to CLDR 40 and Unicode 14
  - Add more locales for Emoji data
  + GDK:
  - Optimize texture conversions on x86 and ARM
  - Use EGK_KHR_swap_buffers_with_damage if available
  + GSK:
  - Avoid clearing opaque regions
  - Support using a non-default framebuffer
  - Handle large viewports by tiling
  + Wayland:
  - Prefer xdg-activation over gtk-shell
  - text protocol: Fix text caret location
  - text protocol: Use serials to control outbound messages
  + Inspector: Show app ID and resource path
  + Demos: widget-factory: Handle F11 to toggle fullscreen
  + Tools: gtk-builder-tool: Allow use without display
  + Updated translations.
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gtk4-tools = %%%%{version} to devel sub-package.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.1:
  + GtkFontChooser:
  - Stop using PangoFc api
  - Fix a crash
  - Use new HarfBuzz api
  + GtkMenuButton: Update accessible description
  + GtkTextView: Fix intra-widget dnd
  + Printing: Fix an fd leak
  + Input:
  - Make sure input methods get focus-in events
  - Always flush events to avoid scroll event pileup
  - Support hold events
  - Update keysyms from libxkbcommon
  + Theme: Improve text selection legibility
  + Introspection: Add missing nullable annotations everywhere
  + Build:
  - Make stack noexec again
  - Avoid symbol leaks
  - Drop unneeded script data
  + Wayland:
  - Fix support for the new high-contrast setting
  - Avoid redundant scale changes
  - Fix DND hotspot handling
  - Don't always restore the saved size when floating
  + Updated translations.
- Drop gtk4-make-our-stack-noexec.patch: Fixed upstream.
* Fri Jan  7 2022 Teoh Han Hui <teohhanhui@gmail.com>
- Add gtk4-make-our-stack-noexec.patch: Make our stack noexec.
* Thu Dec 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.6.0:
  + GtkProgressBar: Fix handling of "inverted".
  + GtkLabel: Add a "natural wrap mode" property to influence how
    natural width is determined.
  + GtkTextView: Scroll insertion on-screen after undo / redo.
  + gsk: Abort region diffing when changes are too complex.
  + gdk:
  - Avoid compressing discrete scroll events.
  - Fix problems with hiding windows.
  - Improve GL and GLES version checks.
  + Wayland: Support new high-contrast setting.
  + Inspector: Add DND inspection support.
  + build: Avoid deprecated meson apis.
  + Updated translations.
* Sat Dec 18 2021 Florian "spirit" <packaging@sp1rit.anonaddy.me>
- Update to version 4.5.1:
  + GtkWidget sizing has been rewritten to implement
    width-for-height more properly. This had some fallout, and some
    widgets may still not react kindly to the new way of doing
    things. See https://blog.gtk.org/2021/12/03/sizable-news/ for
    details, and please file issues if you notice fallout.
  + Rename git `master` branch to `main`
  + Css:
  - Fully support font-variant-caps
  - Fix a crash with gradients
  + Make various widgets activatable:
  - GtkComboBox
  - GtkDropDown
  + GtkPopover: Make focus indicators not disappear
  + GtkTextView:
  - Don't leave embedded children stranded when scrolling
  - Don't insert Emoji into non-editable textviews
  - Fix Emoji chooser positioning
  - Fix problems with pasting text
  - Improve scroll-to-mark behavior
  - Support right-aligned, centered and decimal tabs
  - Make child anchor replacement character settable
  - Provide more context to input methods
  + GtkDragIcon: Provide default icons for paintables and files
  + GtkBuilder: Speed up template precompilation
  + Actions:
  - Reduce allocations during signal emissions
  - Avoid duplication and unnecessary recursion
  + Inspector:
  - Show the selected im-module in the General tab
  - Add a clipboard viewer
  - Make the recorder record events too
  - Add a graph visualizing gtk_widget_measure()
  + Gsk:
  - Fix hexbox rendering
  - Fix transformed linear gradient rendering
  + Printing: Fix dialog-less printing
  + X11:
  - Improve behavior of windows drags on headerbar controls
  - Trap errors for RANDR changes
  - Fix problems with drag icons
  + Wayland: Ensure we prefer the Wayland im-module over others
  + Updated translations.
- Changes from version 4.5.0:
  + gsk:
  - Drop the GL renderer in favor of NGL
  - Rename NGL to GL
  - Fix some coordinate overflow issues
  - Reimplement texture upload and download for better support of
    image formats and color spaces
  - New api:
  * gsk_transform_skew
  * gsk_transform_to_2d_components
  + gdk:
  - Support HSL in gdk_rgba_parse
  - Use libpng, libjpeg and libtiff directly when loading
    textures, and support more image formats (including 16bit and
    float formats)
  - New apis:
  * gdk_texture_new_from_bytes
  * gdk_texture_new_from_filename
  * gdk_texture_download_float
  * gdk_texture_save_to_png_bytes
  * gdk_texture_save_to_tiff
  * gdk_texture_save_to_tiff_bytes
  * gdk_display_create_gl_context
  - Implement GIcon and GLoadableIcon in GdkTexture
  - Move EGL initialization to the frontend
  - Use configless EGL contexts, if supported
  - Use >8bit pixel formats, if supported and requested
  + css:
  - Add support for line-height
  - Add support for text-transform
  + theme: Fixes for buttons in toolbars
  + input:
  - Update compose sequences from libX11 1.7.2
  - Accept replacement string longer than 20 characters
  + text:
  - Implement sloped caret drawing
  - Add a gtk-hint-font-metrics setting to switch font rendering
    to be more similar to GTK3
  + GtkTextView:
  - Add support for line height
  - Add support for text transforms
  - Misc fixes for css->pango attribute translations
  - Invalidate pango contexts when font settings change
  - Improve undo grouping when overwriting
  + GtkListView:
  - Make tree indentation more flexible with
    GtkTreeExpander:indent-for-icon
  + GtkMenuButton: Support custom children
  + GtkFlowBox: Add prepend and append
  + GtkCalendar: Fix handling of weeks starting on Monday
  + GtkWindow: Add a titlebar property
  + GtkDropDown: Add a show-arrow property
  + GtkPopoverMenu: Support a use-markup attribute in menu models
  + Add GtkSymbolicPaintable
  + Tools: Support DND in gtk4-node-editor and the inspector's
    recorder
  + Demos: Improve the font rendering demo
  + Build:
  - Require Pango 1.49
  - Require libpng, libtiff and libjpeg
  - Speed up handling of resources during build
  + X11: Support touchpad gestures with XInput 2.4
  + Updated translations.
- Drop gtk4-fix-link-to-g_signal_emit.patch: fixed upstream.
- Add docutils, pkgconfig(libjpeg), pkgconfig(libpng) and
  pkgconfig(libtiff-4) BuildRequires: New dependencies.
* Sat Nov 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop baselibs.conf, there should not be any consumers of 32bit
  for this rather new package, so lets not build for the past.
* Thu Nov 11 2021 Yifan Jiang <yfjiang@suse.com>
- Add gtk4-fix-link-to-g_signal_emit.patch: fix build failure
  caused by inproper link to g_signal_emit.
* Thu Nov  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Disable sassc BuildRequires, only needed when building from git.
- Add pkgconfig(gi-docgen) and  pkgconfig(iso-codes) BuildRequires
  and pass gtk_doc=true to meson instead of documentation=true
  following upstream changes. Also split develdocumentation out
  into it's own sub-package.
- Drop pkgconfig(json-glib-1.0) BuildRequires, not needed nor used.
- Replace option print-backends=all with print-cups=enabled
  following upstream changes.
- Stop passing xinerama=enabled to meson, not needed nor used.
- Add pkgconfig(tracker-sparql-3.0) BuildRequires and pass
  tracker=enabled to meson, build with tracker support.
* Mon Nov  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.4.1:
  + input:
  - Fix compose data on bigendian systems
  - Accept long replacement strings for compose sequences
  + a11y:
  - Fix accessible relations for menu buttons
  - Fix accessible descriptions in some cases
  - Simplify atspi context a bit
  + GtkTextView:
  - Fix applying css properties such as letterspacing, line
    decoration, font features, etc
  - Improve grouping for undo
  - Invalidate Pango contexts when font settings change
  - Fix a crash
  + Theme: Improve styling for toggle buttons in toolbars
  + gsk: Avoid coordinate overflow with big text selections
  + GtkFileChooser: Fix handling of choices
  + GtkStackSwitcher: Expand child buttons
  + GtkCalendar: Fix day names for weeks that start on monday
  + GtkWindow: Prefer menubars when handling F10
  + GtkFontButton: Make sure the dialog is on the same display
  + X11: Fix handling of randr events
  + build: Fix detection of pre-compiled css files
  + Updated translations.
* Sun Oct  3 2021 Fuminobu Takeyama <ftake@geeko.jp>
- Fix a syntax error in the gtk4_immodule_postun RPM macro
* Thu Sep 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add explicit pkgconfig(gstreamer-gl-1.0) BuildRequires: not new,
  but tested by meson, so let's be explicit about the dependency.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Aug 25 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.4.0:
  + Input:
  - Match IBus for display of Compose sequences
  - Match IBus for handling of mismatches
  - Handle Escape in Compose sequences
  - Allow multiple dead keys
  - Support 32bit keysyms
  + GtkCheckButton: Activate when moving focus
  + GtkLabel: Propertly ignore double underscores for mnemonics
  + GtkPopoverMenu: Fix focus cycling
  + GtkTextView:
  - Improve word selection
  - Fix block cursors on empty lines
  + GdkToplevel: Support the gnome-shell titlebar gesture protocol
  + GdkDropTarget: Allow creating drop targets in ui files
  + gsk:
  - Handle partial color fonts correctly
  - Use harfbuzz for color font information
  - Avoid pango for glyph cache rendering
  - Shrink shadow extents
  + Settings: Change the default for gtk-split-cursor to FALSE
  + Demos:
  - Small improvements to widget-factory
  - gtk-demo: Improve the hypertext demo
  - gtk-dem: Improve the clipboard demo
  + X11: Set WM_CLASS on toplevels
  + Wayland: Support wl_seat v7
  + Updated translations.
* Wed Jul 28 2021 Yifan Jiang <yfjiang@suse.com>
- Add back Mesa-libGLESv2-devel BuildRequires for SLE and Leap.
  The necessary header GLES2/gl2ext.h is still in the v2 package on
  SLE/Leap.
* Fri Jun  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move RPM macros to %%_rpmmacrodir.
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.2.1:
  + GtkVideo: Detect stream metadata when using gstreamer
  + GtkFileChooser: Fix a crash
  + GtkButton: Add back visual feedback for keynav activation
  + GtkFontChooser: Fix initial font selection
  + GtkScrolledWindow: Stop using scroll cursors
  + GtkMenuButton: Make focus-on-click work
  + GtkToggleButton: Make grouped buttons mutually exclusive
  + GtkPasswordEntry: Use MADV_DONTDUMP for secure memory
  + GtkListBox: Allow repeated selection extension for MULTIPLE
  + GdkClipboard: Ensure strings are nul-terminated
  + GSK:
  - Fix offscreen rendering with transforms
  - Fix downscaled textures
  - Avoid huge intermediate textures
  - Make shadow rendering match across renderers
  + Text widgets: Support translucent selections
  + Wayland:
  - Improve font settings fallback
  - Avoid unintentional rendering freezes with popovers
  + X11:
  - Don't beep on untrusted displays
  - Don't crash when popovers are outside the workarea
  + Themes:
  - Fix resize border sizing
  - Fix solid-csd window decorations
  + Input:
  - Revert some Compose sequence changes
  - Consume all key events during preedit, to avoid unexpected
    interactions
  - Ignore more modifiers during preedit, to allow using 3rd
    and 5th level choosers
  - Fix handling of cursor positions in non-ASCII preedit text
  - Fix a problem with deferred focus setting
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.2.0:
  + GtkFileChooser: Make the location entry work again.
  + GtlLabel: Fix tooltips on links.
  + GtkTextView: Make scrolling work better with renderers.
  + X11:
  - Fix damage handling.
  - Trap errors from the COW.
  + Wayland: Fix key event matching with mismatched layouts.
  + Inspector: Allow inspecting Unicode.
  + Input:
  - Improve dead key handling.
  - Regenerate compose sequence table.
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.1.2:
  + Input:
  - Ensure preedit-start and preedit-end are emitted properly
  - Support the Wayland text protocol better
  - Delete the selection when preedit starts
  + Label: Fix a small issue with markup parsing and mnemonics
  + Spinbutton: Interpret localized digits.
  + Textview: Fix blinking block cursors.
  + Tooltips: Don't pop up erroneous on popovers.
  + Window: Add a way to disable F10 handling.
  + Theme: Use a regular focus ring for sidebar rows.
  + GSK:
  - ngl: Performance improvements.
  - vulkan: Add visible fallback rendering.
  - vukan: Handle simple transforms when clipping.
  + Wayland:
  - Don't force a full redraw for every frame.
  - Don't leak buffers when rendering with cairo.
  + Demos: iconbrowser: Make search more useful.
  + Documentation: Switch to building docs from gir files with
    gi-docgen.
  + build: Allow GTK to be used as meson subproject.
  + Updated translations.
- Drop gtk-doc BuildRequires: doc building was moved to gi-docgen,
  but we are not just yet ready to consume this, and also have not
  been bulding docs before.
* Fri Feb 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.1.1:
  + Popover: Support shadows on popover > contents.
  + Input:
  - Show preedit for compose sequences.
  - Support long compose sequences.
  - Support compose sequences producing multiple characters.
  + Themes:
  - Allow suggested and destructive actions in lists.
  - Disable shadows on maximized, fullscreen and tiled windows.
  - Fine-tune scrollbar transitions and size.
  + CSS:
  - Support drop-shadow filters.
  - Correct blur filter spread interpretation.
  + Documentation: Improvements and updates for dialogs and native
    dialog.
  + Printing: Support Avahi-discovered printers better.
  + GSK: Add another OpenGL render. It is not the default yet.
  + Build:
  - Lots of static analysis fixes found by pvs.
  - Add a -Dprofile=devel option for devel styling and use it for
    nightly flatpaks.
  + X11: Fix DND of X11-specific types.
  + Wayland: Fix lookup of font settings in flatpaks.
  + Updated translations.
* Wed Feb  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.1.0:
  + GtkCheckButton: Add back an activate signal.
  + GtkSearchBar, GtkSearchEntry: Capture events in the bubble
    phase.
  + GtkEmojiChooser: Adapt to small screen sizes.
  + GtkVideo: Fix issues with GL support.
  + Themes:
  - Set sort arrows in CSS.
  - Set menu button arrows in CSS.
  - Make scrollbars larger.
  - Supprt circular menubuttons.
  + CSS:
  - Implement transform-origin.
  - Support overlines on text.
  - Support colors in cross-fade().
  - More complete text-decoration-line support.
  + Text layout: Use subpixel positioning with new enough cairo.
  + Inspector:
  - Fix slowness in navigation.
  - Redo the controllers and shortcuts pages.
  + Accessibility: Create AT context objects lazily.
  + Wayland: Fix decoration negotiation under kwin.
  + GSK:
  - Optimize gradient shaders.
  - Implement repeating gradients in shaders.
  + Updated translations.
- Add Mesa-libGLESv3-devel BuildRequires: new dependency.
* Sun Jan 31 2021 Marguerite Su <i@marguerite.su>
- Fix macros.gtk4:
  + gtk4 has no gtk4-query-immodules
    "GTK+ 4.0 will not support IM modules, and has moved to GIO
    extension points"
  + https://blog.gtk.org/2018/03/06/input-methods-in-gtk-4/
* Tue Jan 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.0.2:
  + GtkAboutDialog:
  - Set icon size for the logo.
  - Fix initial focus to be the same as in GTK 3.
  + GtkImage: Update icons on scale change.
  + Wayland: Fix crashes with touch and tablet events.
  + Windows:
  - Fix surface and geometry computation.
  - Remove layered window usage.
  + MacOS: Support stylus devices.
  + Themes:
  - Adwaita: Remove edge highlights.
  - Adwaita: Update image assets.
  - Make Adwaita-dark available as standalone theme.
  - Make HighContrastInverse the dark variant of HighContrast.
  + Docs:
  - Complete GtkAspectFrame docs.
  - Clarify migration docs for widget signals.
  + Inspector:
  - Fix a critical with the recorder.
  - Fix a crash with treeviews.
  - Show overlay layout properties.
  - Add a legend for the layout overlay.
  + Build:
  - Fix build with gcc 11.
  - Support building without sassc.
  + Updated translations.
- Switch back to regular releases: with GTK 4 having a consumer
  (GNOME 40) the focus is much more active on it now.
* Mon Jan 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Rename libgtk-4-0 to libgtk-4-1: the library changed soname with
  version 4.0.0.
- Obsolete libgtk-4-0 > 4 by libgtk-4.1: this is a bit a special
  hack, but we know that versions < 4 were indeed libgtk-4-.so.0,
  and starting from version 4, it should have been renamed.
* Sat Jan  9 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.1:
  + GtkPopover:
  - Center titles
  - Fix menu item alignment with submenus
  + GtkVideo:
  - Fix up autoplay semantics
  - Respect pixel aspect ratio
  - Get GL textures from gstreamer
  + GtkCenterLayout: Fix handling of expanding center child
  + GtkSettings:
  - Change gtk-cursor-aspect-ratio to double
  - Fix the default value of gtk-print-backends
  + GtkGestureStylus: Convert motion history to surface coordinates
  + GL renderer:
  - Various optimizations
  - Avoid leaking shader objects
  + Adwaita:
  - Fine-tune flat buttons
  - Improve contrast of dim-label
  - Improve contrast of controls in headers
  + Docs:
  - Add various missing types
  - Add DND examples
  - Correct css docs for several widgets
  - Improve GtkVideo docs
  - Update migration docs for GtkClipboard
  - Improve migration docs for event controllers
  - Add migration docs for GtkBuilder
  + gtk4-builder-tool:
  - Remove GtkCheckButton::draw-indicator
  - Fix a buffer overrun
  - Remove GtkToolbar::toolbar-style
  + Demos:
  - Don't put the search bar in the scroll area
  - Make the OpenGL demos work with OpenGL ES
  + X11: Fix a possible crash
  + Build:
  - Fix vulkan reference in pc file
  - Fix build with certain Vulkan versions
  + Updated translations.
* Sat Dec 26 2020 bjorn.lie@gmail.com
- Update to version 4.0.0+107:
  + Remove unused static inline function
  + Fix some of gtk4-demo’s transitions example on OpenGL ES
  + Fix gtk4-demo’s gears demo on OpenGL ES
  + gdkarray: Add a "stolen" boolean to splice()
  + listview: Use the correct scroll policy
  + docs:
  - Put render nodes in their own sections
  - Add examples for GtkDropTarget
  - Add examples of GtkDragSource use
  - Fix typo and whitespace
  - backtick fixes
  - Fix list of kinds of shortcuts in Keyboard input
  - Add missing GTK types
  - Note the caveat on GtkEditable signals with delegates
  + roundedbox: Remove unused API
  + picture: Fix copy/paste error in docs
  + video: When autoplaying, start playing once the video is
    prepared
  + window: Release application in destroy
  + Fix warnings with Vulkan < 162
  + modelbutton: Remove an unused field
  + Fix buffer overruns in 'gtk-builder-tool simplify'
  + Fix the value for the print-backends setting
  + inspector: Show glyphs as in node files
  + gsk:
  - Export the glyph serialization privately
  - Improve glyph serialization
  - Fix serialization of glyphs
  + box: improve documentation
  + gskpango:
  - Don't copy fg color
  - Correct a comment
  - Remove bounds rect
  - Fix a potential cairo_t leak
  + label:
  - Refactor get_layout_location()
  - Refactor snapshot()
  + textlayout: Remove dead offset_y code
  + rendernode:
  - Different uniformity in border nodes
  - Sort diff() requirements by complexity
  + renderborder: Avoid 0 width outline color nodes
  + layoutoverlay:
  - Avoid adding transparent color nodes
  - Avoid adding 0 sized color nodes
  + gl renderer:
  - Check for pointer equality in rounded_rect_equal
  - Proper state tracking for color matrix ops
  - Add missing debug output for repeat ops
  - Create shader-global uniform ops on draw()
  - Unify new clip/viewport rects in blur_texture()
  - Avoid setting modelview to identical values
  - Take a out graphene_rect in blur_node()
  - Render too big textures to the clipped area
  - Unify viewport setting in add_offscreen_ops()
  + GskTransform:
  - Add nullable annotations to _equals()
  - Fix identity transform class name
  - Avoid a ref+unref pair
  + icontheme:
  - Make some constant values const
  - Make icon_paintable_ensure_texture() return an unowned value
  + pixbufutils: Only convert icon size to string once
  + main: Add & use gdk_event_dup_axes()
  + Call the newly installed gtk4-update-icon-cache
  + Pass the bindir to the post-install script
  + Revert "gl renderer: Render too big textures to the clipped
    area"
  + Revert "gl renderer: Take a out graphene_rect in blur_node()"
  + 3to4:
  - Add test for GtkCheckButton:draw-indicator removal
  - Remove GtkCheckButton:draw-indicator
  + Do not build gdk-pixbuf's man page
  + a11y: Fix removing mnemonic widgets
  + Notify properties on deletion in PasswordEntryBuffer
  + Fix URLs for the download.gnome.org locations
  + Adwaita: flat button adjustments
  + vulkancontext: Remove usage of
    VK_ERROR_INCOMPATIBLE_VERSION_KHR
  + Updated translations.
- Switch to source service, upstream is not moving fast enough, and
  we need this to fix a buildfail due to updated vulkan.
* Wed Dec 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.0:
  + Fix problems with synthetic motion events affecting frame rates
  + Fix problems with implicit grabs affecting widget states
  + Fix problems with zoom mode on scales getting stuck
  + Fix submenu closing by outside clicks
  + Rename GtkWindow:fullscreen to :fullscreened to help language
    bindings
  + Bump the soname. Stable GTK 4 releases use
    libgtk-4.0.so.1.xxxx.y
  + Adwaita:
  - Reduce hover transition effects in lists
  - Special-case header buttons
  + Demos:
  - Remove NoDisplay from desktop files
  - Autoplay the video in widget-factory
  + Updated translations.
- Changes from version 3.99.5:
  + Accessibility:
  - Map presentation role according to Core-AAM
  - Use presentation role for spacers in list views
  - Set proper roles, relations and descriptions on more widgets
  - Expand the documentation
  - Use a single GTK_A11Y environment variable and document it
  - Serveral memory leak and crash fixes
  - Initialize AT contexts lazily
  - Improve the API for storing lists in relations
  - Implement more of the Component interface
  - Implement the Cache interface
  - Implement ScrollSubstringTo for GtkTextView
  + Introspection:
  - Add many missing annotations to APIs
  - In particular, nullability annotation fixes for rust
  + Touch support:
  - Fix issues with text handles
  - Fix interaction between touch scrolling and focus
  - Fix active state updates for touch events
  - Allow pressing buttons with multiple fingers
  + GtkScrolledWindow: Accumulate velocity with kinetic scrolling
  + GtkSearchEntry: Use a better clear icon
  + GtkTreeView: Remove the deprecated
    GtkCellRendererClass.get_size vfunc
  + GtkBuilder:
  - Be stricter about <requires>
  - Make gtk-builder-tool simplify update <requires>
  + GtkFileChooser: Remove GtkFileChooserButton
  + GtkWindow:
  - Replace gtk_window_get_size with gtk_window_get_default_size
  - Add maximized and fullscreen properties
  + Make the inspector available in non-debug builds
  + CSS: Support conic gradients
  + Adwaita:
  - Round all window corners
  - Round submenus
  - Remove the 'chin' on menus
  - Industrial style menuitems
  - Improved tooltip styling
  - Unified sidebar styles
  - Dark prelight
  - Don't backdrop labels
  + GSK: Rename render node apis from peek to get
  + Make GLES work in the absence of GL_ARB_timer_query
  + Rework the way size allocation is integrated in the frame cycle
  + Wayland:
  - Support gtk_shell1 version 3 (startup notification and
    activation)
  - Implmement minimization
  + Documentation:
  - Add missing enumerations, symbols and types
  - Lots of smaller fixes
  + Demos:
  - Make the constraints demo more useful
  - Make search more obvious
  - Add a suggestion entry demo
  - Consistency improvements
  - Use native file choosers
  - Drop 'devel' styling
  + Updated translations.
* Tue Nov 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.4:
  + GtkColumnView:
  - Improve column resizing
  - Make double-click reset column widths
  - Move header outside of scrollbars
  + GtkSearchEntry: Add an icon
  + GtkDropDown: Polish the appearance
  + GtkColorChooser: Accessibility improvements
  + GtkPopoverMenu:
  - Add accessibility support
  - Allow custom items. This adds new API:
    gtk_popover_menu_add/remove_child
    gtk_popover_menu_bar_add/remove_child
  + GtkTextView:
  - Fix rendering and positioning of anchored children
  - Fix positioning of touch handles
  + Constraints: Fix loading constraints from ui files
  + Media support: Use cubic instead of linear volume
  + Accessibility:
  - Implement Component for all widgets
  - Implement Text and EditableText for all editables
  - Rework accessible name/description computation
  - Add documentation for app and widget developers
  - Handle HIDDEN state changes by adding/removing elements
  - Support setting accessibility attributes in ui files
  - Make window controls accessible
  + Introspection: Add some missing annotations
  + gdk:
  - Deliver events on flush
  - Drop the unused GdkPoint struct from the API
  - Improve popup autohide behavior
  + Demos:
  - Add another constraints demo
  - Tweak various demos to improve consistency
  - Small accessibility improvements
  + Tools: Improve gtk4-builder-tool handling of various widgets
    when converting ui files from GTK 3
  + Documentation:
  - Use GtkApplication in all examples
  - Improve and expand the widget gallery
  + Testsuite:
  - Improve coverage of GDK
  - Improve coverage of gtk4-builder-tool
  + Build:
  - Fix the build with cups 2.2.12
  - Make cloudprint support build without warnings
  + Broadway: Support modifiers for scroll events
  + Updated translations.
- Changes from version 3.99.3:
  + Accessibility: Add an initial AT-SPI backend
  + GtkEmojiChooser:
  - Allow inserting multiple Emoji by pressing Control
  - Update Emoji data to Unicode 13 / CLDR 37
  - Use translations
  - The recent-emoji setting type changed. Call gsettings reset
    org.gtk.gtk4.Settings.EmojiChooser recent-emoji
  + GtkTextBuffer: Add boolean returns to some get_iter functions
  + GtkScale: Change the default value of the :draw-value property
  + GtkPopover: Avoid losing focus when popovers are close
  + GtkColorChooser: Add color names back for accessibility
  + Input methods: Add a 'private' input hint
  + GL Renderer:
  - Fix issues with texture caching
  - Fix texture flipping problems
  + Build:
  - Use meson yield feature for some options
  - Require gtk-doc 1.33
  - Require sysprof 3.38
  + Wayland:
  - Clean up Wayland backend api, add annotations
  - Generate introspection for Wayland backend api
  + Demos:
  - Add another column view demo
  - Add an svg paintable demo
  + Updated translations.
- Add pkgconfig(libavfilter) BuildRequires, new dependency, build
  ffmpeg backend.
* Wed Sep 30 2020 dimstar@opensuse.org
- Update to version 3.99.2:
  + GtkButton: Check coordinates for button releases.
  + GtkColorChooser: Update the default palette.
  + GtkEntry:
  - Fix issues with Emoji insertion.
  - Fix issues with dnd.
  - Set correct hotspot for dnd icon.
  + GtkFileChooser:
  - Fix a crash.
  - Fix setting unlisted filters.
  + GtkFontChooser:
  - Determine sample text based on font coverage.
  - Allow filtering by language.
  - Don't center the list.
  + GtkMenuButton: Always use the direction property for the arrow.
  + GtkPasswordEntry:
  - Use non-pageable memory.
  - Add an ::activate signal.
  + GtkRevealer: Fix clipping issues in the swing transitions.
  + GtkScrolledWindow: Fix kinetic scrolling in X11.
  + GtkSearchEntry: Don't handle forwarded events twice.
  + GtkStack: Add gtk_stack_add_child.
  + GtkTextView:
  - Fix dnd.
  - Improve undo state tracking.
  - Speed rendering in the presence of selections.
  - Make clickable links work again.
  - Fix handling of anchored children.
  + GtkVideo: Make autoplay work.
  + CSS:
  - Allow more than 64 selectors per rule.
  - Avoid some allocation overhead.
  + Adwaita:
  - Improve gesture graphics.
  - Tweak DND highlight color.
  - Add spacing to .navigation-sidebar.
  + GDK:
  - Add gdk_frame_clock_get_fps.
  - GLES: Fix color channel mixup in textures.
  - GL: Reduce image copying for texture uploads.
  + GSK:
  - Add radial gradient nodes.
  - Add GskGLShader and shader nodes.
  + GL renderer:
  - Fix clipping with projective transforms.
  - Use linear interpolation for offscreen rendering with
    non-axis-aligned transforms.
  - Fix texture caching to avoid size mismatches.
  - Avoid downloading GL textures when possible, improving
    GtkGLArea performance.
  + Vulkan renderer: Fix swapchain creation.
  + Wayland
  - Always ack configure to avoid jumping windows.
  - Use the primary-selection-unstable-v1 protocol.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.99.1:
  + GtkGridLayout: Rename left-/top-attach to column/row.
  + Drop GtkAccelLabel - it is no longer used.
  + GtkTextView:
  - Fix redraw issues with selections
  - Make insert-emoji replace the selection
  + GtkTreeView: Fix selection handling in cell editables.
  + GtkPopover: Allow setting popup offset.
  + GtkPlacesSidebar: Fix DND.
  + GtkTextview: Speed up gtk_text_buffer_insert_markup.
  + GtkFrame: Set GTK_OVERFLOW_HIDDEN.
  + GtkSpinButton: Fix spinning.
  + GtkFontChooser: Populate the list incrementally.
  + GtkButton: Simplify the button hierarchy; GtkRadioButton is
    gone, GtkCheckButton and GtkToggleButton can be grouped.
  + list widgets:
  - Change apis to make models explicitly GtkSelectionModel.
  - Simplify constructors.
  + CSS:
  - Hexadecimal colors can now specify alpha.
  - Fix parsing of numbers in scientific notation.
  + Themes:
  - Add and document highlevel list styles.
  - Drop the style class defines. Just use string literals.
  - Round the corners of frames.
  - Make circular buttons square.
  + GL renderer: Fix clipping with projective transforms.
  + Printing: Fix build with cups < 2.3.
- Changes from version 3.99.0:
  + Remove the old accessibility implementation and add the
    foundations for a new one that is based on ARIA. The relevant
    widget api is GtkAccessible, the backend implementations will
    use GtkATContext.
  + Update the GTK headers to use char *, int, float and double
    instead of the corresponding GLib types.
  + Add GtkEditableLabel, a label that can be edited.
  + Add GtkBookmarkList, a list model for bookmarks.
  + Add GtkStringList, a list model for strings.
  + Add GtkBitset, and use it for representing selections.
  + GtkTreeView: Make cell editing work again.
  + GtkSpinButton: Make autosizing work again.
  + Printing: Use GtkDropDown in the print dialog.
  + GtkApplication Support opening files on OS X.
  + GtkFileChooser:
  - Fix libcloudproviders support.
  - Turn GtkFileFilter into a GtkFilter.
  - Simplify the api.
  + GtkGridView, GtkListView:
  - Improve scrolling behavior.
  - Autoscroll and autoexpand during DND.
  + GtkScrolledWindow: Make autoscrolling work again.
  + GtkFilterListModel:
  - Add incremental filtering.
  - Add a boolean filter, GtkBoolFilter.
  + GtkSortListModel:
  - Use timsort.
  - Add various tweaks that massively speed up sorting.
  - Add incremental sorting.
  + GtkWidget: Massively speed up action handling.
  + GtkEntry:
  - Make entry completion work again.
  - Drop action support from GtkEntryCompletion.
  + Inspector:
  - Improve list model support.
  - Add direct navigation between objects.
  - Show accessibility information.
  + GSK: Use GL_ARB_framebuffer_object.
  + Updated translations.
- Drop gtk4-cups-2.2.patch: fixed upstream.
* Mon Aug 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.98.5:
  + Introduce new list widgets and supporting infrastructure.
  + GtkFileChooser:
  - Add a tracker3-based search engine implementation.
  - Rate-limit updates from the trash monitor.
  + GtkWindow:
  - Redo the css node setup. There is now a single 'window' node.
  - Fix rounded corners on tiled windows.
  + GtkApplication: Drop app menu support. Menubar support is still
    there.
  + GtkFixed: Change coordinate APIs to take doubles.
  + GtkOverlay: Make GtkOverlayLayout public.
  + GtkTooltips: Fix line wrapping of tooltips.
  + Shortcuts:
  - Fix mnemonic cycling.
  - Fix using '0' as a mnemonic.
  + Menus: Differentiate keypad keys in accelerators.
  + GtkIMContext: Add gtk_im_context_filter_key to allow event
    reinjection.
  + Themes: Adwaita: Limit the scope of backdrop.
  + Accessibility: Clean up and reorganize the code to prepare for
    the dropping of ATK.
  + GDK:
  - Drop unused enum and struct definitions from headers.
  - Make keymap translation API public again. Still needed.
  - Frameclock: Always use compositor refresh rate info.
  - Frameclock: Use quadratic correction for frame time jitter.
  - Frameclock: Ensure monotonicity.
  - Frameclock: Track resason for paint.
  - X11: Improve sync when the Nvidia driver is used.
  + GSK:
  - GL renderer: Fix blurred outset shadows.
  - GL renderer: handle nested transform nodes properly.
  - GL renderer: Optimize clip handling.
  + gtk-demo:
  - Improve the Drag-and-Drop demo with proper drag icons.
  - Don't show the main window if --run is given.
  - Add demos for list widgets and GtkDropDrown.
  + Documentation:
  - Convert freestanding sections to markdown.
  - Drop the glossary.
  - Expand and improve the migration guide.
  + Build:
  - We require pandoc now, for building the documentation.
  - Require Pango 1.45.
  + Updated translations.
- Add gtk4-cups-2.2.patch: Fix build with cups < 2.3.
* Tue May 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.98.4:
  + Themes:
  - Refine menu styling
  - Tweak visible focus behavior
  - HighConstrast: Add public colors
  - HighContrast: Fix scale borders
  + CSS:
  - Drop the nonstandard -gtk-icon-theme property
  - Add a system_setting_changed vfunc to propagate global
    changes
  + Untangle titlebars from windows:
  - Add a GtkWindowControls widget
  - Add a GtkWindowHandle widget
  - Add actions for window menu items
  - Remove app menu fallback from GtkHeaderBar
  - Remove title and subtitle properties from GtkHeaderBar,
    rename custom-title to title-widget
  + GtkWidget: Add a focusable property
  + GtkPopover:  Fix (re-)positioning issues
  + GtkStack:
  - Drop the homogeneous property
  - Add a use-underline property to stack pages
  + GtkScale: Make area around the trough clickable
  + GtkScrolledWindow: Fix kinetic scrolling
  + GtkTreeView: Break reference cycles in unroot
  + Drop GtkBin and GtkContainer. All existing GtkBin subclasses
    have grown a child property with setter and getter. All
    existing GtkContainer subclasses have grown widget-specific
    remove (and in some cases, add) functions. <child> in ui
    files continues to work as before
  + Replace gtk_widget_destroy by gtk_window_destroy
  + Drop the ::size-allocate signal. Use a GtkWidgetPaintable if
    you need to be informed about changes to a widgets content or
    size
  + Remove gtk_dialog_run
  + GDK:
  - Wayland: Provide a builtin cursor of last resort
  - Change the monitor api to use a GListModel
  + GSK:
  - Don't include renderer-specific headers automatically
  - GL: Fix nested rounded clips
  + Introspection: Assorted annotation fixes
  + Inspector:
  - Preview media resources
  - Show media backend information
  + gtk4-widget-factory:
  - Add GtkVideo
  - Add text styles
  - Add a print dialog
  - Add a password entry
  - Improve toolbar styling
  - Revamp transition effects
  + gtk4-demo: Replace some demos
  + Updated translations.
* Tue Apr 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.98.3:
  + GtkEntry: Support setting attributes in ui files
  + GtkScaleButton: Don't derive from GtkButton
  + GtkAboutDialog: Support more common licenses
  + GtkEmojiChooser: Improve keyboard navigation
  + GtkLabel: Remove pattern API
  + GtkAspectFrame: Modernize and simplify
  + Chooser buttons: Make dialogs modal by default
  + Various widgets: Replace shadow-type and relief properties by a
    simpler has-frame
  + CSS:
  - Use :focus-visible instead of :focus(visible)
  - Add support for :focus-within
  + Focus handling
  - Fix crossing event generation
  - Fix focus handling in various widgets
  - Change :can-focus to be recursive
  - Fix GtkWindow:is-active setting
  + Scrolling
  - gtk_container_set_focus_[hv]adjustment has been removed
  - gtk_viewport_set_scroll_to_focus has been added
  + Accessibility:
  - Add a cursor-aspect-ratio setting
  - Set focus-related states properly
  + Themes:
  - Use blue focus outlines more
  - Numerous minor improvements
  + Wayland:
  - Fix .Compose file loading
  - Support popup repositioning
  - Fix problems with autohide popovers
  + GDK:
  - Remove GdkKeymap from public API, replaced by GdkDevice
    properties
  - Add full keyboard translation state to key events
  - Simplify modifier support, drop GdkModifierIntent
  - Move key event matching to GDK
  - Add GdkSurface::enter/leave-monitor signals
  - Turn GskEvent into a derivable type, and make it
    introspectable
  + GSK:
  - Turn GskRenderNode into a derivable type, and make it
    introspectable
  - Fall back to cairo if compiling shaders fails
  + Updated translations.
* Wed Apr  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.98.2:
  + Introduce GtkShortcutController, and replace key bindings,
    mnemonics and accelerators by GtkShortcut
  + Derive the HighContrast theme from Adwaita
  + GtkMenuButton: Add a use-underline property
  + GtkTreeView: Fix cell editing
  + Add gdk_toplevel_inhibit_system_shortcuts
  + gtk-demo: Fix issues in multiple demos
  + Updated translations.
* Sun Mar 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.98.1:
  + GtkFileChooser:
  - Remove filename/uri api
  - Drop extra-widget
  - Remove overwrite confirmation
  - Remove show-hidden property
  - Remove local-only property
  - Remove GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER
  - The portal file chooser supports selecting folders
  + GtkSpinner: Rename active property to spinning
  + GtkRevealer: Fix size allocation at small scales
  + GtkPopover: Drop :relative-to, it is always the :parent now
  + GtkWindow: Drop window-type, it is always a regular toplevel
  + GtkWidget:
  - Drop expand property
  - Drop margin property
  - Drop gtk_grab_add, gtk_device_grab_add
  + GtkTextView:
  - Support overlines in GtkTextTag
  - Support visible spaces in GtkTextTag
  - Support hyphenation control in GtkTextTag
  + Split GtkEventControllerFocus from GtkEventControllerKey
  + DND:
  - Fix local DND to avoid serialization
  - Add new content provider constructors
  - Split GtkDropTargetAsync and GtkDropTarget
  - Group DND events into event sequences
  - Propagate DND events like motion events
  - Introduce GtkDropControllerMotion
  - Remove GtkSelectionData
  + Performance:
  - Clean up profiler marks
  - Share GL programs between renderers
  + GDK:
  - Drop gdk_surface_new_temp
  - Make GdkEvent an immutable boxed type, not an object
  - Remove GdkAtom and property- and selection-related apis
  - Introduce GdkPopup and GdkToplevel interfaces
  - Implement them in backend-specific surface subtypes
  - Rename gdk_surface_input_shape_combine_region to
    gdk_surface_set_input_region
  - Drop X11-only concepts such as sticky or keep-below
  + Broadway: implement scaling
  + Updated translations.
- Drop gtk4-wayland-includes.patch: Fixed upstream.
- Run spec-cleaner, modernize spec.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.98.0:
  + The DND refactoring has been completed.
  + Child surfaces have been removed.
  + Global positions and related apis such as gdk_surface_move are
    no longer available.
  + A constraint-based layout manager has been added.
  + Many classes have been made explicitly non-subclassable, and
    the widget hierarchy has been simplified, by making widgets
    derive directly from GtkWidget instead of a container.
  + Menu-related changes:
  - GtkMenu, GtkMenuBar and related classes have been removed.
  - Context menus are no longer created with ::populate-popup
    signals, but use menu models and actions.
  - Widget actions can be created in class_init, with
    gtk_widget_class_install_action.
  - GtkToolbar has been removed as well.
  + Text-related changed:
  - Text cursor blinking has been made smooth.
  - GtkTextView is caching rendernodes for the visible text range
    now, improving the scrolling performance of text.
  - Add a simple undo stack for text edits has been added.
  + GtkTreeView renders tree and grid lines with textures.
  + GtkEmojiChooser has been made public.
  + GtkGestureMultiPress has been renamed to GtkGestureClick.
  + GtkWidget has api to handle style classes.
  + X11-specific changes:
  - XI2 is now mandatory.
  - The xim input method has been removed.
  + Wayland-specific changes: The loading of cursor themes has been
    improved to load cursors on demand, and no longer relies on
    libwayland-cursor.
  + The GL renderer is now sharing icon and glyph caches for all
    surfaces, and has better support for blurring and shadow
    rendering.
  + Performance-related changes:
  - GTK provides profiling information for Sysprof when launched
    with GTK_TRACE=1.
  - Css computation has been optimized.
  - Css lookups are using a Bloom filter.
  - Icon loading IO has been moved to a thread.
- Add sassc buildRequires: new dependency.
- Add gtk4-wayland-includes.patch: Fix missing dependency exposed
  by our special wayland packagers wish to not have the wayland
  headers in the default locations.
* Tue Sep 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- No longer provide/obsolete gtk3-schema: upstream changed the
  schema names for gtk4 finally and cut compatibility with gtk3. So
  from now on, we have gtk3-schema and gtk4-schema in parallel.
* Fri Sep  6 2019 Luke Jones <luke@ljones.dev>
- Update to version 3.96.0:
  + DND has been refactored. There are now separate GdkDrag and
    GdkDrop objects. This work is still incomplete
  + The GDK_SURFACE_SUBSURFACE surface type has been removed.
  + Use of child surfaces has been greatly reduced. This work is still
    incomplete
  + The use of global coordinates in GDK apis has been reduced. This
    work is still incomplete
  + Events have been simplified and are used just for input
  - expose events have been replaced by a GdkSurface::render signal
  - configure events have been replaced by a
    GdkSurface::size-changed signal
  - map events have been replaced by a GdkSurface::mapped property
  - gdk_event_handler_set has been replaced by a GdkSurface::event
    signal
  - key events no longer contain a string
  - events on unmapped widgets are ignored
  + Warping the pointer is no longer supported
  + The Wayland backend now uses the Settings portal for GtkSettings
  + The Wayland input module uses the text-input-unstable-v3 protocol
  + The Broadway backend has been rewritten to work well with GSK
  + The color chooser has a color picker
  + GtkApplication tracks screensaver state and has a ::query-end
    signal
  + The file chooser portal backend supports file filters
  + A number of list models have been introduced, for internal use
    and as public api:
  - GtkMapListModel
  - GtkSliceListModel
  - GtkSortListModel
  - GtkSelectionModel
  - GtkSingleSelection
  + Support for tabular menus and combo boxes has been dropped
  + Key themes are no longer supported
  + GtkInvisible has been dropped
  + A GtkRoot interface has been added that is currently implemented
    just by GtkWindow. This work is incomplete
  + GtkWidgets can transform their children using projective linear
    transformations. This functionality is available in CSS and
    as GskTransform argument to gtk_widget_allocate. GtkFixed is
    a container that exposes this functionality. For examples of this,
    see the swing transition of GtkRevealer, the rotate transitions
    of GtkStack or the Fixed Layout example in gtk-demo.
  + GtkEntry functionality has been moved into a new GtkText widget,
    the GtkEditable interface has been expanded, and new a new
    GtkPasswordEntry widget has been introduced.
  + Focus handling has been rewritten, and focus-change event
    generation has been unified with crossing events.
  + All demos and settings schemas have been renamed to avoid
    collisions with GTK3.
  + GtkWidget can now use a GtkLayoutManager for size allocation.
    Layout managers can optionally use layout children holding layout
    properties. A number of layout managers are available:
  - GtkBinLayout
  - GtkBoxLayout
  - GtkGridLayout
  - GtkFixedLayout
  - GtkCustomLayout
    More layout manager implementations will appear in the future.
  + GtkAssistant, GtkStack and GtkNotebook now have publicly
    accessible page objects for their children. The page objects
    are also exposed via a list model.
  + GtkContainer no longer supports child properties. All existing
    child properties have been removed, converted to regular properties,
    moved to layout properties or moved to child meta objects.
  + GtkListBox has gained a ::show-separators property that gets
    translated into a CSS style class.
  + A number of X11-specific GtkWindow and GdkSurface apis have been
    removed or changed to backend APIs.
  + GtkBuilder can specify object-valued properties inline.
  + The gtk4-builder-tool simplify command has gained a --3to4 option
    to convert GTK3 ui files to GTK4.
  + The inspector can show child meta objects and layout properties.
- Remove gtk4-fix-dependency-error.patch, fixed upstream.
* Fri Sep 28 2018 bjorn.lie@gmail.com
- Update options passed to meson, bring back lost support for
  broadway and cloudprint following upstreams changes.
* Tue Sep 18 2018 luc14n0@linuxmail.org
- Add gtk4-fix-dependency-error.patch upstream patch to fix build
  error with few threads raised by missing dependency on
  broadwayjs.h (glgo#GNOME/gtk#1218).
- Update spec:
  + Drop gtk4 subpackages and respective Recommends/Requires/\
    Provides tags to follow upstream changes while placing
    Obsolets tags for them: immodule-amharic, immodule-broadway,
    immodule-inuktitut, immodule-multipress, immodule-thai,
    immodule-tigrigna, immodule-vietnamese, immodule-xim and data.
  + Drop gtk4-tools Requires(post): this no longer needed.
  + Drop lang subpackage Recommends: the main package is already
    being supplemented by the lang subpackage due to RPM automatic
    setting.
  + Drop gtk4-data Provides: there's no such subpackage anymore.
  + Drop glib2_gsettings_schema_requires macro: this is no longer
    needed since RPM file triggers (version > 4.13).
* Thu Aug  9 2018 tchvatal@suse.com
- Fix package name to be uniform immodules -> immodule
  (bsc#1104264).
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.94.0:
  + GdkPaintable is a new, powerful abstraction for drawable
    content.
  + gtk4-demo has a new "Paint" demo to show some of its
    capabilities.
  + There is support for displaying media, with GtkVideo,
    GtkMediaFile, GtkMediaStream and GtkMediaControls.
  + GtkFontChooser now supports OpenType font variations and
    features.
  + The Ctrl-Shift-E support in the simple IM context has been
    replaced by an optional completion popup for Emoji alpha codes.
    This can be enabled with the GtkEntry::enable-emoji-completion
    property.
  + Wayland has an input method based on the text protocol now.
  + Input methods, print backends and media backends have been
    converted to GIOModules and extension points, and support for
    generic loadable modules has been dropped. Platform im modules
    are always included.
  + GdkWindow has been renamed to GdkSurface.
  + Applications can now create their own GtkSnapshot objects for
    intermediate rendering.
  + Widget event signals have been replaced by event controllers,
    and some new event controllers have been introduced for this:
    GtkEventControllerMotion, GtkEventControllerKey and
    GtkGestureStylus.
  + Event controllers can now be created in .ui files.
  + Invalidation tracking has been changed, only
    gtk_widget_queue_draw is left.
  + Observing widget contents and size is now done by using the
    GtkWidgetPaintable object instead of connecting to widget
    signals.
  + The GtkWidget::draw signal has been removed, widgets need to
    implement GtkWidget::snapshot.
  + GdkTexture now has GdkMemoryTexture and GdkGLTexture
    subclasses.
  + The Vulkan support in GDK can now use a particular device that
    is specified by the GDK_VULKAN_DEVICE environment variable. Use
    GDK_VULKAN_DEVICE=list to see them all.
  + GTK+ Inspector:
  - has logging support, and the logging settings have been
    cleaned up.
  - has an fps overlay.
  + Removed APIs and features: Individual event signals such as
    ::proximity-in-event The ::draw signal threading support
    non-platform IM modules papi and test print backends
    GtkPlacesSidebar GtkRecentChooser GtkToolPalette
    GdkStatus gtk_true, gtk_false gtk_widget_show_now
    gtk_widget_draw gtk_render_icon_surface.
  + Incomplete transitions:
  - The ::event signal is not still there, but it will be
    removed.
  - The DND apis are not finalized yet.
  + Updated translations.
- Drop gtkmm.patch: Fixed upstream.
- Add pkgconfig(gstreamer-player-1.0) BuildRequires: New
  dependency.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 28 2018 dimstar@opensuse.org
- Add gtkmm.patch: Allow binding GdkContentFormatsBuilder.
* Fri Dec 29 2017 jengelh@inai.de
- Sync summaries within package.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 3.93.0:
  + GdkScreen has been removed. All screen-related APIs have
    equivalents in GdkDisplay.
  + GdkVisual has been removed.
  + GdkDeviceManager has been replaced by GdkSeat.
  + Clipboard handling has been moved from GTK to GDK, and has been
    modernized to provide an extensible, asynchronous, stream-based
    API.
  + The GdkCursor API has been modernized.
  + Settings and window-state changes have been converted from
    events to signals on GdkDisplay and GdkWindow, respectively.
  + GdkEvent has been converted to an opaque GObject.
  + The GL renderer in GSK has been substantially completed, and is
    now on par with the Vulkan renderer.
  + The use of GdkPixbuf in APIs has been reduced, and the
    GskTexture object has been moved to GDK as GdkTexture, to take
    its place.
  + The handling of icon sizes has been changed.
  + Bugs fixed: bgo#668590, bgo#773299, bgo#775279, bgo#777072,
    bgo#779009, bgo#779862, bgo#783995, bgo#784314, bgo#785176,
    bgo#785210, bgo#786123, bgo#787089, bgo#787128, bgo#787142,
    bgo#787665, bgo#788841, bgo#788898, bgo#789054, bgo#789134,
    bgo#789149, bgo#789160, bgo#789163, bgo#789198, bgo#789213,
    bgo#789327, bgo#789357, bgo#789678, bgo#789733, bgo#789777,
    bgo#789870, bgo#790029, bgo#790031, bgo#790171, bgo#790201,
    bgo#790287, bgo#790489, bgo#790920, bgo#790963, bgo#791062,
    bgo#791176, bgo#791281, bgo#791363, bgo#791549, bgo#791650,
    bgo#791926, bgo#791927.
  + Updated translations.
- Drop gtk4-return-nonvoid.patch: fixed upstream.
- Add cairo-gobject, gobject-2.0, pangocairo, xrender and
  graphene-gobject-1.0 pkgconfig modules BuildRequires complying
  with meson checks. Note that all of these modules were being
  pulled and used already since the spec file had some depedencies
  on other modules that come from the same devel package as these
  ones.
* Thu Oct 19 2017 dimstar@opensuse.org
- Update to version 3.92.1:
  + Drop autotools support. Meson 0.42.1 is now required.
  + Implement most of CSS3 font-variant.
  + Add an Emoji chooser to GtkEntry.
  + Add new input hints for Emoji input.
  + Remaining widgets have been ported to GtkSnapshot.
  + GtkLabel and GtkEntry have been ported to use GSK.
  + Add a way for GtkOverlay to blur behind children. This has a
    demo in gtk4-demo.
  + Add support for libcloudproviders in GtkPlacesSidebar.
  + Non-windowed widgets are now allowed to have a size of 0x0.
  + Allow tiled windows to be resized. Under wayland, this uses
    version 2 of the gtk-shell protocol. Under X, it uses the
    _GTK_EDGE_CONSTRAINTS property.
  + Input handling changes:
  - GdkEvent has new accessors for fields;
  - Traditional event signals (eg ::key-press-event) are now
    emitted from an event controller;
  - Most widgets inside gtk have stopped using traditional event
    signals;
  - GDK_SEAT_CAPABILITY_ALL_POINTING now includes touch events.
  + Scrollbars allow middle-click to jump to a position again.
  + Bugs fixed: bgo#639931, bgo#644248, bgo#701296, bgo#705640,
    bgo#728452, bgo#763517, bgo#766909, bgo#773299, bgo#775074,
    bgo#775126, bgo#778382, bgo#778811, bgo#780750, bgo#780758,
    bgo#781757, bgo#782981, bgo#783649, bgo#783669, bgo#784016,
    bgo#784421, bgo#785210, bgo#785306, bgo#785736, bgo#786144,
    bgo#786209, bgo#786400, bgo#786469, bgo#786485, bgo#786492,
    bgo#786553, bgo#786613, bgo#786673, bgo#786794, bgo#786885,
    bgo#786931, bgo#786932, bgo#786938, bgo#786940, bgo#786956,
    bgo#786960, bgo#786964, bgo#786966, bgo#787021, bgo#787103,
    bgo#787172, bgo#787279, bgo#787302, bgo#787303, bgo#787410,
    bgo#787416, bgo#787444, bgo#787531, bgo#787600, bgo#787669,
    bgo#787757, bgo#787866, bgo#788230, bgo#788458, bgo#788534,
    bgo#788573, bgo#788614, bgo#788787, bgo#788905.
  + Updated translations.
- Add meson BuildRequires and replace configure/make/make_install
  calls with meson/meson_build and meson_install: follow upstreams
  port to meson as build system.
- Add gcc-c++ BuildRequires: small parts of GTK+ now are written in
  C++.
- Add gtk-doc BuildRequires: in order to build man-pages,
  documentation needs to be enabled, which in turn requires
  gtk-doc. In the past, we provided upstream shipped documentation.
- Add gtk4-return-nonvoid.patch: Fix 'reaches end of non-void
  function without return value', taken from git.
- Add rpmlintrc: multiple GTK4 libraries are not goint to be
  supported in parallel and the name will stabilize.
* Thu Sep 14 2017 fezhang@suse.com
- Drop the SLE12 / Leap42 build_wayland_backend conditional, build
  with wayland unconditionally.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 3.91.2:
  + All widgets are drawing CSS backgrounds and borders.
  + All gadgets have been replaced by widgets.
  + GtkSpinButton no longer derives from GtkEntry.
  + GtkScrollbar no longer derives from GtkRange.
  + GtkAccelLabel no longer derives from GtkLabel.
  + All remaining style properties have been removed.
  + A new 'widget bowl' demo has been added in gtk4-demo.
  + GtkEventBox has been removed. It is no longer needed.
  + Add support for entering emoji by name using Ctrl-Shift-e.
  + Wayland:
  - Support Wacom tablet wheel scrolling.
  - Support the shortcut inhibitor protocol.
  + Bugs fixed: bgo#776903, bgo#776909, bgo#777333, bgo#777515,
    bgo#778188, bgo#780938, bgo#781246, bgo#783343, bgo#783906,
    bgo#784016, bgo#784624, bgo#785280, bgo#785318, bgo#785375,
    bgo#785423, bgo#785672, bgo#785793.
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.91.1:
  + Redo event delivery and focus handling and grabs, and stop
    using subwindows for widgets. API changes due to this include:
  - A new GtkWidget::pick vfunc.
  - Drop event mask apis.
  - Drop windows from gestures.
  + The prelight state is now automatically set on widgets.
  + New widget: GtkCenterBox. This widget provides the center child
    functionality that used to be part of GtkBox.
  + Wayland:
  - Improve the key repeat implementation.
  - Set vid/pid on tablet devices.
  + OS X: Add native file chooser support.
  + Bugs fixed: bgo#745289, bgo#759308, bgo#766517, bgo#770513,
    bgo#772281, bgo#773299, bgo#775636, bgo#781285, bgo#781583,
    bgo#781935, bgo#781945, bgo#782040, bgo#782283, bgo#783047,
    bgo#783347, bgo#783397, bgo#783445, bgo#783587, bgo#784323,
    bgo#784723, bgo#784888.
  + Updated translations.
- Drop post(un) handling for gtk4-devel and gtk4-schema as we have
  file-triggers to take care of this for us now.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.91.0:
  + Initial support for OS X has been merged.
  + Initial support for building with meson has been added.
  + New API: gtk_widget_insert_before/after.
  + Removed API:
  - GtkBox has lost its expand and fill child properties, use the
    general align property for it.
  - GtkLabel has lost its angle property, it will be replaced by
    general widget transformation support in the future.
  - GtkWindow has lost its hide-titlebar-when-maximized property.
  - GtkBox has lost its center child support.
  - The compat keysym definitions have been removed.
  + Bugs fixed: bgo#769881, bgo#771269, bgo#778301, bgo#778853,
    bgo#779078, bgo#779184, bgo#780041, bgo#780301, bgo#780734,
    bgo#780878, bgo#780944, bgo#781162, bgo#781195, bgo#781214,
    bgo#781422, bgo#781622, bgo#781737, bgo#781767, bgo#781992,
    bgo#782109, bgo#782202.
  + Updated translations.
* Sat Apr  1 2017 zaitor@opensuse.org
- Update to version 3.90.0:
  + Allow a custom renderer for the inspector, by setting
    GTK_INSPECTOR_RENDERER.
  + Move more container functionality, such as focus handling, to
    GtkWidget.
  + Bugs fixed: bgo#686838, bgo#778853, bgo#779081, bgo#780019,
    bgo#780234, bgo#734946, bgo#773228, bgo#774148, bgo#780735.
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.89.5:
  + Convert many more widgets to use gtk_widget_measure for size
    allocation.
  + gtk3-demo: Add an example for touchpad swipe handling.
  + Theme: Improve styling for flow boxes.
  + Quartz:
  - Support fullscreen CSD windows.
  - Implement backdrop.
  - Implement gdk_window_set_functions.
  + Bugs fixed: bgo#136059, bgo#734946, bgo#772505, bgo#776821,
    bgo#778019, bgo#778203, bgo#778534, bgo#778678, bgo#778726,
    bgo#778746, bgo#779073, bgo#779074, bgo#779147, bgo#779317,
    bgo#779374, bgo#779383, bgo#779392.
  + Updated translations.
* Tue Feb 28 2017 dimstar@opensuse.org
- Fix baselibs.conf: do not build gtk4-tools-32bit.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.89.4:
  + API changes:
  - gtk_init and other init functions no longer take commandline
    arguments.
  - Functions that are only useful with commandline arguments
    have been dropped.
  - Widgets, except for toplevels, are now visible by default.
  - Style properties are no longer supported.
  + Vulkan rendrerer: Implement more clipping.
  + CSS: Specifying px for pixels is now required.
  + Bugs fixed: bgo#358970, bgo#770112, bgo#773299, bgo#773686,
    bgo#775864, bgo#776225, bgo#777363, bgo#777547, bgo#778009.
  + Updated translations.
- Changes from version 3.89.3:
  + GtkWidget now has API to navigate child widgets:
  - gtk_widget_get_{first,last}_child and
    gtk_widget_get_{prev,next}_sibling.
  - A number of non-container widgets have been converted to use
    child widgets internally: GtkSwitch, GtkSpinButton,
    GtkActionBar.
  + GtkAboutDialog can show a 'System' tab.
  + GTK+ CSS now supports the filter: property and a
  - gtk-icon-filter function that replaces and generalizes
  - gtk-icon-effect.
  + GtkInspector can now save render nodes for testing and
    debugging.
  + More tests for render nodes have been added.
  + GtkTreeView and cell renderers have been more completely
    converted to the snapshot() api.
  + More widgets have been converted to snapshot(): GtkCalendar,
    GtkColorPlane.
  + Vulkan renderer:
  - Combine draw calls when possible.
  - Handle (some) clipping on the GPU.
  - Handle linear gradients.
  - Handle opacity.
  - Support color transformations.
  - Handle borders.
  + Wayland: Support the Vulkan renderer.
  + X11: Call XInitThreads(), since this is needed with Mesa Vulkan
    drivers.
  + Mir:
  - Implement window properties.
  - Track the focus window.
  - Connect to content-hub and use it for copy/paste.
  - Support modal windows.
  + Bugs fixed: bgo#775732, bgo#775846, bgo#776524, bgo#776560,
    bgo#776604, bgo#776627, bgo#776807, bgo#776868, bgo#777176.
  + Updated translations.
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 3.89.2:
  + gtk4-icon-browser works again.
  + gtk-encode symbolic works for icons with names containing dots.
  + GtkFlowBox and GtkListBox have been changed to no longer emit
    the ::selected-children-changed signal during destruction.
  + gtk-demo has gained an example for using PangoTabArray with
    GtkTextView.
  + We now support CSS border-spacing in GtkGrid, GtkBox and in
    gadgets.
  + The rendering in GDK and GSK has been further refactored. We
    now only draw toplevel windows, and we always redraw the whole
    window.
  + A Vulkan implementation has been added in parallel to the GL
    one.
  + Dropped APIs:
  - gdk_window_process_updates.
  - gdk_window_process_all_updates.
  - gdk_window_reparent.
  - Support for native and foreign subwindows.
  - gsk_render_node_{append/prepend/insert} variations.
  - gsk_render_node_make_immutable.
  - gtk_cairo_should_draw_window.
  - gtk_snapshot_append.
  - GtkJunctionSides.
  + New APIs:
  - gdk_rgba_is_clear.
  - gdk_rgba_is_opaque.
  - GdkDrawContext: A base class for vulkan and gl contexts.
  - Render node subclasses.
  - GskRoundedRect.
  - gtk_container_snapshot_child.
  + The GSK_USE_SOFTWARE environment variable has been generalized
    as GSK_RENDERER. Use GSK_RENDERER=help to learn about possible
    values. Other environment variables that have gained new
    possible values in clude GSK_DEBUG=vulkan and
    GTK_DEBUG=snapshot.
  + Bugs fixed: bgo#749012, bgo#771242, bgo#772371, bgo#773299,
    bgo#774265, bgo#774534, bgo#774686, bgo#774695, bgo#774743,
    bgo#774760, bgo#774784, bgo#774790, bgo#774893, bgo#774915,
    bgo#774917, bgo#774939, bgo#775038, bgo#775212, bgo#775316,
    bgo#775319, bgo#775410, bgo#775525, bgo#775651, bgo#776132,
    bgo#776187, bgo#776306.
  + Updated translations.
- Drop gtk4-find-wayland.patch: Fixed upstream. Following this,
  drop gnome-common BuildRequires and autoreconf call as we no
  longer carry any patches.
- Add vulkan-devel BuildRequires and Requires, also pass
  - -enable-vulkan to configure to ensure we build the vulkan
  support.
* Fri Dec  9 2016 dimstar@opensuse.org
- Split out glib schemas into gtk4-schema: gtk3 and gtk4 share the
  same schema (in order to sync their config changes). With this
  split we can have gtk4-schema provide/obsolete gtk3-schema and
  get around the two conflicting on file level.
- Move relevant %%gsettings macros from -data to -schema package.
- Require gtk4-schema by libgtk-4-0.
- Provide/Obsolete gtk3-schema by gtk4-schema.
- Split out gettext-its-gtk4.
* Fri Dec  9 2016 jengelh@inai.de
- Update summaries and groups
* Mon Dec  5 2016 dimstar@opensuse.org
- Initial package, gtk4, version 3.89.1.
